@@ -135,8 +135,6 @@ class AedtLogger(object):
         self._files_handlers = []
         self._projects = {}
 
-        # if not self._global.handlers:
-        #     self._global.addHandler(log_handler.LogHandler(self, "Global", logging.DEBUG))
         self._global.setLevel(level)
         self._global.addFilter(AppFilter())
 
@@ -181,7 +179,6 @@ class AedtLogger(object):
     def add_file_logger(self, filename, project_name, level=None):
         """Add a new file to the logger handlers list."""
         _project = logging.getLogger(project_name)
-        # _project.addHandler(log_handler.LogHandler(self, "Project", level if level else self.level))
         _project.setLevel(level if level else self.level)
         _project.addFilter(AppFilter("Project", project_name))
         _file_handler = logging.FileHandler(filename)
@@ -292,6 +289,7 @@ class AedtLogger(object):
             self._timer = time_val
         else:
             self._timer = time.time()
+        return self._timer
 
     def get_messages(self, project_name=None, design_name=None, level=0, aedt_messages=False):
         """Get the message manager content for a specified project and design.
@@ -558,7 +556,6 @@ class AedtLogger(object):
         if destination == "Project":
             project_name = self._project_name
             self._project = logging.getLogger(project_name)
-            # self._project.addHandler(log_handler.LogHandler(self, "Project", level))
             self._project.setLevel(level)
             self._project.addFilter(AppFilter("Project", project_name))
             if self._files_handlers:
@@ -571,7 +568,6 @@ class AedtLogger(object):
             project_name = self._project_name
             design_name = self._design_name
             self._design = logging.getLogger(project_name + ":" + design_name)
-            # self._design.addHandler(log_handler.LogHandler(self, "Design", level))
             self._design.setLevel(level)
             self._design.addFilter(AppFilter("Design", design_name))
             if self._files_handlers:
@@ -629,7 +625,7 @@ class AedtLogger(object):
         """Write an info message to the global logger."""
         if args:
             try:
-                msg1 = msg % [str(i) for i in args]
+                msg1 = msg % tuple(str(i) for i in args)
             except TypeError:
                 msg1 = msg
         else:
@@ -637,11 +633,13 @@ class AedtLogger(object):
         self._log_on_dekstop(0, msg1, "Global")
         return self._log_on_handler(0, msg, *args, **kwargs)
 
-    def info_timer(self, msg, *args, **kwargs):
+    def info_timer(self, msg, start_time=None, *args, **kwargs):
         """Write an info message to the global logger with elapsed time.
         Message will have an appendix of type Elapsed time: time."""
-        td = time.time() - self._timer
-        m, s = divmod(time.time() - self._timer, 60)
+        if not start_time:
+            start_time = self._timer
+        td = time.time() - start_time
+        m, s = divmod(td, 60)
         h, m = divmod(m, 60)
         d, h = divmod(h, 24)
         if d > 0:
@@ -652,7 +650,7 @@ class AedtLogger(object):
             msg += " Elapsed time: {}m {}sec".format(round(m), round(s))
         if args:
             try:
-                msg1 = msg % [str(i) for i in args]
+                msg1 = msg % tuple(str(i) for i in args)
             except TypeError:
                 msg1 = msg
         else:
@@ -664,7 +662,7 @@ class AedtLogger(object):
         """Write a warning message to the global logger."""
         if args:
             try:
-                msg1 = msg % [str(i) for i in args]
+                msg1 = msg % tuple(str(i) for i in args)
             except TypeError:
                 msg1 = msg
         else:
@@ -676,7 +674,7 @@ class AedtLogger(object):
         """Write an error message to the global logger."""
         if args:
             try:
-                msg1 = msg % [str(i) for i in args]
+                msg1 = msg % tuple(str(i) for i in args)
             except TypeError:
                 msg1 = msg
         else:
@@ -688,7 +686,7 @@ class AedtLogger(object):
         """Write a debug message to the global logger."""
         if args:
             try:
-                msg1 = msg % [str(i) for i in args]
+                msg1 = msg % tuple(str(i) for i in args)
             except TypeError:
                 msg1 = msg
         else:
