@@ -11,9 +11,9 @@ from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.Model2D import Modeler2D
-from pyaedt.modeler.Model3D import Modeler3D
-from pyaedt.modeler.stackup_3d import Stackup3D
+from pyaedt.modeler.advanced_cad.stackup_3d import Stackup3D
+from pyaedt.modeler.modeler2d import Modeler2D
+from pyaedt.modeler.modeler3d import Modeler3D
 from pyaedt.modules.Mesh import Mesh
 from pyaedt.modules.MeshIcepak import IcepakMesh
 
@@ -122,7 +122,7 @@ class FieldAnalysis3D(Analysis, object):
 
         Returns
         -------
-        :class:`pyaedt.modeler.Model3D.Modeler3D` or :class:`pyaedt.modeler.Model2D.Modeler2D`
+        :class:`pyaedt.modeler.modeler3d.Modeler3D` or :class:`pyaedt.modeler.modeler2d.Modeler2D`
         """
         return self._modeler
 
@@ -463,16 +463,18 @@ class FieldAnalysis3D(Analysis, object):
         return self.export_3d_model(fileName, filePath, fileFormat, object_list, removed_objects)
 
     @pyaedt_function_handler()
-    def export_3d_model(self, fileName, filePath, fileFormat=".step", object_list=None, removed_objects=None):
+    def export_3d_model(
+        self, file_name="", file_path="", file_format=".step", object_list=None, removed_objects=None, **kwargs
+    ):
         """Export the 3D model.
 
         Parameters
         ----------
-        fileName : str
+        file_name : str, optional
             Name of the file.
-        filePath : str
+        file_path : str, optional
             Path for the file.
-        fileFormat : str, optional
+        file_format : str, optional
             Format of the file. The default is ``".step"``.
         object_list : list, optional
             List of objects to export. The default is ``None``.
@@ -489,7 +491,31 @@ class FieldAnalysis3D(Analysis, object):
 
         >>> oEditor.Export
         """
+        if "fileName" in kwargs:
+            warnings.warn(
+                "`fileName` is deprecated. Use `file_name` instead.",
+                DeprecationWarning,
+            )
 
+            file_name = kwargs["fileName"]
+        if "filePath" in kwargs:
+            warnings.warn(
+                "`filePath` is deprecated. Use `file_path` instead.",
+                DeprecationWarning,
+            )
+
+            file_path = kwargs["filePath"]
+        if "fileFormat" in kwargs:
+            warnings.warn(
+                "`fileFormat` is deprecated. Use `file_format` instead.",
+                DeprecationWarning,
+            )
+
+            file_format = kwargs["fileFormat"]
+        if not file_name:
+            file_name = self.project_name + "_" + self.design_name
+        if not file_path:
+            file_path = self.working_directory
         if object_list is None:
             object_list = []
         if removed_objects is None:
@@ -510,7 +536,7 @@ class FieldAnalysis3D(Analysis, object):
         major = -1
         minor = -1
         # actual version supported by AEDT is 29.0
-        if fileFormat in [".sm3", ".sat", ".sab"]:
+        if file_format in [".sm3", ".sat", ".sab"]:
             major = 29
             minor = 0
         stringa = ",".join(allObjects)
@@ -523,7 +549,7 @@ class FieldAnalysis3D(Analysis, object):
             "Selections:=",
             stringa,
             "File Name:=",
-            os.path.join(filePath, fileName + fileFormat).replace("\\", "/"),
+            os.path.join(file_path, file_name + file_format).replace("\\", "/"),
             "Major Version:=",
             major,
             "Minor Version:=",
@@ -904,6 +930,7 @@ class FieldAnalysis3D(Analysis, object):
     @pyaedt_function_handler()
     def flatten_3d_components(self, component_name=None, purge_history=True, password=""):
         """Flatten one or multiple 3d components in the actual layout. Each 3d Component is replaced with objects.
+        This function will work only if the reference coordinate system of the 3d component is the global one.
 
         Parameters
         ----------
@@ -920,8 +947,13 @@ class FieldAnalysis3D(Analysis, object):
         bool
             `True` if succeeded.
         """
+        native_comp_names = [i.props["BasicComponentInfo"]["ComponentName"] for _, i in self.native_components.items()]
         if not component_name:
-            component_name = self.modeler.user_defined_component_names
+            component_name = [
+                key
+                for key, val in self.modeler.user_defined_components.items()
+                if val.definition_name not in native_comp_names
+            ]
         else:
             if isinstance(component_name, str):
                 component_name = [component_name]
@@ -935,8 +967,23 @@ class FieldAnalysis3D(Analysis, object):
             if purge_history:
                 app.modeler.purge_history(app.modeler._all_object_names)
             self.modeler.set_working_coordinate_system(comp.target_coordinate_system)
-            self.copy_solid_bodies_from(app, no_vacuum=False, no_pec=False, include_sheets=True)
-            app.close_project(save_project=False)
+            if self.design_type == "Icepak":
+                objs_monitors = [part.name for _, part in comp.parts.items()]
+                monitor_cache = {}
+                for mon_name, mon_obj in self.monitor.all_monitors.items():
+                    obj_name = mon_obj.properties["Geometry Assignment"]
+                    if obj_name in objs_monitors:
+                        monitor_cache.update({mon_obj.name: mon_obj.properties})
+            oldcs = self.oeditor.GetActiveCoordinateSystem()
+            self.modeler.set_working_coordinate_system(
+                self.modeler.user_defined_components[cmp].target_coordinate_system
+            )
             comp.delete()
+            self.copy_solid_bodies_from(app, no_vacuum=False, no_pec=False, include_sheets=True)
+            self.modeler.set_working_coordinate_system(oldcs)
+            if self.design_type == "Icepak":
+                for _, mon_dict in monitor_cache.items():
+                    self.monitor.insert_monitor_object_from_dict(mon_dict, mode=1)
+            app.close_project(save_project=False)
             self.modeler.refresh_all_ids()
         return True
