@@ -1,10 +1,9 @@
 from pyaedt.application.Analysis import Analysis
-from pyaedt.modeler.Circuit import ModelerMaxwellCircuit
+from pyaedt.modeler.schematic import ModelerMaxwellCircuit
 
 
 class AnalysisMaxwellCircuit(Analysis):
-    """Class for Maxwell Circuit (MaxwellCircuit)
-
+    """Provides the Maxwell Circuit (MaxwellCircuit) interface.
     Maxwell Circuit Editor has no setup, solution, analysis or postprocessor
     It is automatically initialized by Application call (Maxwell Circuit).
     Refer to Application function for inputs definition
