@@ -1,6 +1,6 @@
 from pyaedt.application.Analysis import Analysis
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.Model2D import ModelerRMxprt
+from pyaedt.modeler.modeler2d import ModelerRMxprt
 from pyaedt.modules.PostProcessor import CircuitPostProcessor
 
 
