@@ -276,11 +276,10 @@ def decompose_variable_value(variable_value, full_variables={}):
             float_value = float(variable_value)
         except ValueError:
             # search for a valid units string at the end of the variable_value
-            loc = re.search("[a-z_A-Z]+", variable_value)
+            loc = re.search("[-+]?(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?", variable_value)
             units = _find_units_in_dependent_variables(variable_value, full_variables)
-
             if loc:
-                loc_units = loc.span()[0]
+                loc_units = loc.span()[1]
                 extract_units = variable_value[loc_units:]
                 chars = set("+*/()[]")
                 if any((c in chars) for c in extract_units):
@@ -642,11 +641,14 @@ class VariableManager(object):
     def __init__(self, app):
         # Global Desktop Environment
         self._app = app
+        self._variables = {}
 
     @pyaedt_function_handler()
     def __delitem__(self, key):
         """Implement del with array name or index."""
         self.delete_variable(key)
+        if key in self._variables:
+            del self._variables[key]
 
     @pyaedt_function_handler()
     def __getitem__(self, variable_name):
@@ -676,21 +678,24 @@ class VariableManager(object):
             Dictionary of the specified variables.
 
         """
-        var_dict = {}
         all_names = {}
         for obj in object_list:
-            listvar = self._get_var_list_from_aedt(obj)
-            for variable_name in listvar:
-                variable_expression = self.get_expression(variable_name)
-                all_names[variable_name] = variable_expression
-                si_value = self._app.get_evaluated_value(variable_name)
-                value = Variable(variable_expression, None, si_value, all_names, name=variable_name, app=self._app)
-                is_number_flag = is_number(value._calculated_value)
-                if independent and is_number_flag:
-                    var_dict[variable_name] = value
-                elif dependent and not is_number_flag:
-                    var_dict[variable_name] = value
-        return var_dict
+            variables = self._get_var_list_from_aedt(obj)
+            for variable_name in variables:
+                if variable_name not in self._variables:
+                    if self.get_expression(variable_name):
+                        variable_expression = self.get_expression(variable_name)
+                        all_names[variable_name] = variable_expression
+                        si_value = self._app.get_evaluated_value(variable_name)
+                        value = Variable(
+                            variable_expression, None, si_value, all_names, name=variable_name, app=self._app
+                        )
+                        is_number_flag = is_number(value._calculated_value)
+                        if independent and is_number_flag:
+                            self._variables[variable_name] = value
+                        elif dependent and not is_number_flag:
+                            self._variables[variable_name] = value
+        return self._variables
 
     @pyaedt_function_handler()
     def get_expression(self, variable_name):
@@ -702,7 +707,14 @@ class VariableManager(object):
         >>> oProject.GetVariableValue
         >>> oDesign.GetVariableValue
         """
-        return self.aedt_object(variable_name).GetVariableValue(variable_name)
+        invalid_names = ["CosimDefinition", "CoSimulator", "CoSimulator/Choices", "InstanceName", "ModelName"]
+        if variable_name not in invalid_names:
+            try:
+                return self.aedt_object(variable_name).GetVariableValue(variable_name)
+            except:
+                return False
+        else:
+            return False
 
     @pyaedt_function_handler()
     def aedt_object(self, variable):
@@ -797,6 +809,8 @@ class VariableManager(object):
         >>> aedtapp.variable_manager.set_variable["$p1"] == "30mm"
 
         """
+        if variable_name in self._variables:
+            del self._variables[variable_name]
         if not description:
             description = ""
 
@@ -1021,9 +1035,18 @@ class VariableManager(object):
     def _get_var_list_from_aedt(self, desktop_object):
         var_list = []
         if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
-            var_list += list(desktop_object.GetChildObject("Variables").GetChildNames())
-        tmp = [i for i in list(desktop_object.GetVariables()) if i not in var_list]
-        var_list += tmp
+            # To retrieve local variables
+            var_list += list(self._app.get_oo_object(self._app.odesign, "LocalVariables").GetPropNames())
+        if self._app._is_object_oriented_enabled() and self._app.design_type in [
+            "Circuit Design",
+            "Twin Builder",
+            "HFSS 3D Layout Design",
+        ]:
+            # To retrieve Parameter Default Variables
+            var_list += list(self._app.get_oo_object(self._app.odesign, "DefinitionParameters").GetPropNames())
+
+        var_list += [i for i in list(desktop_object.GetVariables()) if i not in var_list]
+        var_list += [i for i in list(self._app.oproject.GetArrayVariables()) if i not in var_list]
         return var_list
 
 
@@ -1131,6 +1154,60 @@ class Variable(object):
             )
         return False
 
+    @pyaedt_function_handler()
+    def _set_prop_val(self, prop, val, n_times=10):
+        if self._app.design_type == "Maxwell Circuit":
+            return
+        try:
+            name = "Variables"
+
+            if self._app.design_type in [
+                "Circuit Design",
+                "Twin Builder",
+                "HFSS 3D Layout Design",
+            ]:
+                if self._variable_name in list(
+                    self._app.get_oo_object(self._app.odesign, "DefinitionParameters").GetPropNames()
+                ):
+                    name = "DefinitionParameters"
+                else:
+                    name = "LocalVariables"
+            i = 0
+            while i < n_times:
+                if name == "DefinitionParameters":
+                    result = self._app.get_oo_object(self._aedt_obj, name).SetPropValue(prop, val)
+                else:
+                    result = self._app.get_oo_object(
+                        self._aedt_obj, "{}/{}".format(name, self._variable_name)
+                    ).SetPropValue(prop, val)
+                if result:
+                    break
+                i += 1
+        except:
+            pass
+
+    @pyaedt_function_handler()
+    def _get_prop_val(self, prop):
+        if self._app.design_type == "Maxwell Circuit":
+            return
+        try:
+            name = "Variables"
+
+            if self._app.design_type in [
+                "Circuit Design",
+                "Twin Builder",
+                "HFSS 3D Layout Design",
+            ]:
+                if self._variable_name in list(
+                    self._app.get_oo_object(self._app.odesign, "DefinitionParameters").GetPropNames()
+                ):
+                    return self._app.get_oo_object(self._aedt_obj, "DefinitionParameters").GetPropValue(prop)
+                else:
+                    name = "LocalVariables"
+            return self._app.get_oo_object(self._aedt_obj, "{}/{}".format(name, self._variable_name)).GetPropValue(prop)
+        except:
+            pass
+
     @property
     def name(self):
         """Variable name."""
@@ -1148,219 +1225,115 @@ class Variable(object):
     @property
     def is_optimization_enabled(self):
         """ "Check if optimization is enabled."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Included")
-        return
+        return self._get_prop_val("Optimization/Included")
 
     @is_optimization_enabled.setter
     def is_optimization_enabled(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Included", value)
+        self._set_prop_val("Optimization/Included", value, 10)
 
     @property
     def optimization_min_value(self):
         """ "Optimization min value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Min")
-        return
+        return self._get_prop_val("Optimization/Min")
 
     @optimization_min_value.setter
     def optimization_min_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Min", value)
+        self._set_prop_val("Optimization/Min", value, 10)
 
     @property
     def optimization_max_value(self):
         """ "Optimization max value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Max")
-        return
+        return self._get_prop_val("Optimization/Max")
 
     @optimization_max_value.setter
     def optimization_max_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Max", value)
+        self._set_prop_val("Optimization/Max", value, 10)
 
     @property
     def is_sensitivity_enabled(self):
         """Check if Sensitivity is enabled."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Included")
-        return
+        return self._get_prop_val("Sensitivity/Included")
 
     @is_sensitivity_enabled.setter
     def is_sensitivity_enabled(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Included", value)
+        self._set_prop_val("Sensitivity/Included", value, 10)
 
     @property
     def sensitivity_min_value(self):
         """ "Sensitivity min value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Min")
-        return
+        return self._get_prop_val("Sensitivity/Min")
 
     @sensitivity_min_value.setter
     def sensitivity_min_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Min", value)
+        self._set_prop_val("Sensitivity/Min", value, 10)
 
     @property
     def sensitivity_max_value(self):
         """ "Sensitivity max value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Max")
-        return
+        return self._get_prop_val("Sensitivity/Max")
 
     @sensitivity_max_value.setter
     def sensitivity_max_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Max", value)
+        self._set_prop_val("Sensitivity/Max", value, 10)
 
     @property
     def sensitivity_initial_disp(self):
         """ "Sensitivity initial value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/IDisp")
-        return
+        return self._get_prop_val("Sensitivity/IDisp")
 
     @sensitivity_initial_disp.setter
     def sensitivity_initial_disp(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/IDisp", value)
+        self._set_prop_val("Sensitivity/IDisp", value, 10)
 
     @property
     def is_tuning_enabled(self):
         """Check if tuning is enabled."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Included")
-        return
+        return self._get_prop_val("Tuning/Included")
 
     @is_tuning_enabled.setter
     def is_tuning_enabled(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Included", value)
+        self._set_prop_val("Tuning/Included", value, 10)
 
     @property
     def tuning_min_value(self):
         """ "Tuning min value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Min")
-        return
+        return self._get_prop_val("Tuning/Min")
 
     @tuning_min_value.setter
     def tuning_min_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Min", value)
+        self._set_prop_val("Tuning/Min", value, 10)
 
     @property
     def tuning_max_value(self):
         """ "Tuning max value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Max")
-        return
+        return self._get_prop_val("Tuning/Max")
 
     @tuning_max_value.setter
     def tuning_max_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Max", value)
+        self._set_prop_val("Tuning/Max", value, 10)
 
     @property
     def tuning_step_value(self):
         """ "Tuning Step value."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Step")
-        return
+        return self._get_prop_val("Tuning/Step")
 
     @tuning_step_value.setter
     def tuning_step_value(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Step", value)
+        self._set_prop_val("Tuning/Step", value, 10)
 
     @property
     def is_statistical_enabled(self):
         """Check if statistical is enabled."""
-
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                return oo.GetChildObject(self._variable_name).GetPropValue("Statistical/Included")
-        return
+        return self._get_prop_val("Statistical/Included")
 
     @is_statistical_enabled.setter
     def is_statistical_enabled(self, value):
-        if self._app:
-            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
-            if oo:
-                oo.GetChildObject(self._variable_name).SetPropValue("Statistical/Included", value)
+        self._set_prop_val("Statistical/Included", value, 10)
 
     @property
     def read_only(self):
         """Read-only flag value."""
-        if self._app:
-            try:
-                return (
-                    self._aedt_obj.GetChildObject("Variables")
-                    .GetChildObject(self._variable_name)
-                    .GetPropValue("ReadOnly")
-                )
-            except:
-                return self._readonly
+        self._readonly = self._get_prop_val("ReadOnly")
         return self._readonly
 
     @read_only.setter
@@ -1375,15 +1348,7 @@ class Variable(object):
     @property
     def hidden(self):
         """Hidden flag value."""
-        if self._app:
-            try:
-                return (
-                    self._aedt_obj.GetChildObject("Variables")
-                    .GetChildObject(self._variable_name)
-                    .GetPropValue("Hidden")
-                )
-            except:
-                return self._hidden
+        self._hidden = self._get_prop_val("Hidden")
         return self._hidden
 
     @hidden.setter
@@ -1398,15 +1363,7 @@ class Variable(object):
     @property
     def description(self):
         """Description value."""
-        if self._app:
-            try:
-                return (
-                    self._aedt_obj.GetChildObject("Variables")
-                    .GetChildObject(self._variable_name)
-                    .GetPropValue("Description")
-                )
-            except:
-                return self._description
+        self._description = self._get_prop_val("Description")
         return self._description
 
     @description.setter
@@ -1457,26 +1414,24 @@ class Variable(object):
     @property
     def numeric_value(self):
         """Numeric part of the expression as a float value."""
-        try:
-            if re.search(r"^[\w+]+\[\w+].*", str(self._value)):
-                var_obj = self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name)
-                val, _ = decompose_variable_value(var_obj.GetPropEvaluatedValue("EvaluatedValue"))
-                return val
-        except TypeError:
-            pass
         if is_array(self._value):
             return list(eval(self._value))
-        if is_number(self._value):
-            try:
-                scale = AEDT_UNITS[self.unit_system][self._units]
-            except KeyError:
-                scale = 1
-            if isinstance(scale, tuple):
-                return scale[0](self._value, True)
-            else:
-                return self._value / scale
-        else:
-            return self._value
+        try:
+            var_obj = self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name)
+            val, _ = decompose_variable_value(var_obj.GetPropEvaluatedValue("EvaluatedValue"))
+            return val
+        except (TypeError, AttributeError):
+            if is_number(self._value):
+                try:
+                    scale = AEDT_UNITS[self.unit_system][self._units]
+                except KeyError:
+                    scale = 1
+                if isinstance(scale, tuple):
+                    return scale[0](self._value, True)
+                else:
+                    return self._value / scale
+            else:  # pragma: no cover
+                return self._value
 
     @property
     def unit_system(self):
@@ -1486,11 +1441,18 @@ class Variable(object):
     @property
     def units(self):
         """Units."""
+        try:
+            var_obj = self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name)
+            _, self._units = decompose_variable_value(var_obj.GetPropEvaluatedValue("EvaluatedValue"))
+            return self._units
+        except (TypeError, AttributeError):
+            pass
         return self._units
 
     @property
     def value(self):
         """Value."""
+
         return self._value
 
     @property
@@ -1842,9 +1804,9 @@ class DataSet(object):
             x, y, z, v = (list(t) for t in zip(*sorted(zip(self.x, self.y, self.z, self.v), key=lambda e: float(e[0]))))
         else:
             x, y = (list(t) for t in zip(*sorted(zip(self.x, self.y), key=lambda e: float(e[0]))))
-
+        ver = self._app._aedt_version
         for i in range(len(x)):
-            if self._app._aedt_version >= "2022.1":
+            if ver >= "2022.1":
                 arg3 = ["NAME:Point"]
                 arg3.append(float(x[i]))
                 arg3.append(float(y[i]))
