@@ -162,23 +162,21 @@ def release_desktop(close_projects=True, close_desktop=True):
                 desktop.CloseProject(project)
         pid = _main.oDesktop.GetProcessID()
         if settings.aedt_version >= "2022.2" and settings.use_grpc_api and not is_ironpython:
-            import ScriptEnv
+            if _check_grpc_port(settings.port, settings.machine):
+                import ScriptEnv
 
-            if close_desktop:
-                ScriptEnv.Shutdown()
-            else:
-                ScriptEnv.Release()
+                if close_desktop:
+                    ScriptEnv.Shutdown()
+                else:
+                    ScriptEnv.Release()
             _delete_objects()
-            if settings.remote_api:
-                return True
+            return True
         elif not inside_desktop:
             i = 0
             scopeID = 5
             while i <= scopeID:
                 _main.COMUtil.ReleaseCOMObjectScope(_main.COMUtil.PInvokeProxyAPI, i)
                 i += 1
-        _delete_objects()
-
         if close_desktop:
             try:
                 os.kill(pid, 9)
@@ -187,6 +185,7 @@ def release_desktop(close_projects=True, close_desktop=True):
             except Exception:  # pragma: no cover
                 warnings.warn("Something went wrong in closing AEDT.")
                 return False
+        _delete_objects()
         return True
     except AttributeError:
         _delete_objects()
@@ -290,12 +289,8 @@ def get_version_env_variable(version_id):
     return version_env_var
 
 
-class Desktop:
-    """Initializes AEDT based on the inputs provided.
-
-    .. note::
-       On Windows, this class works without limitations in IronPython and CPython.
-       On Linux, this class works only in embedded IronPython in AEDT.
+class Desktop(object):
+    """Provides the Ansys Electronics Desktop (AEDT) interface.
 
     Parameters
     ----------
@@ -396,26 +391,38 @@ class Desktop:
                 settings.non_graphical = non_graphical
         else:
             settings.non_graphical = non_graphical
+
             if "oDesktop" in dir(self._main):
                 del self._main.oDesktop
             self._main.student_version, version_key, version = self._set_version(specified_version, student_version)
+            if version_key < "2022.2":
+                settings.use_grpc_api = False
+            elif (
+                version_key == "2022.2"
+                and not self.port
+                and not self.machine
+                and settings.use_grpc_api is None
+                and _com != "gprc_v3"
+            ):
+                settings.use_grpc_api = False
+            elif settings.use_grpc_api is None or _com == "gprc_v3":
+                settings.use_grpc_api = True
             if _com == "ironpython":  # pragma: no cover
                 self._logger.info("Launching PyAEDT outside AEDT with IronPython.")
                 self._init_ironpython(non_graphical, new_desktop_session, version)
-            elif _com == "grpc_v3" or settings.use_grpc_api or self.port:
+            elif settings.use_grpc_api:
                 settings.use_grpc_api = True
                 self._init_cpython_new(non_graphical, new_desktop_session, version, self._main.student_version)
             elif _com == "pythonnet_v3":
-                if version_key < "2022.2" or not (settings.use_grpc_api or os.name == "posix" or self.port):
-                    self._logger.info("Launching PyAEDT outside AEDT with CPython and PythonNET.")
-                    self._init_cpython(
-                        non_graphical,
-                        new_desktop_session,
-                        version,
-                        self._main.student_version,
-                        version_key,
-                        aedt_process_id,
-                    )
+                self._logger.info("Launching PyAEDT outside AEDT with CPython and PythonNET.")
+                self._init_cpython(
+                    non_graphical,
+                    new_desktop_session,
+                    version,
+                    self._main.student_version,
+                    version_key,
+                    aedt_process_id,
+                )
             else:
                 from pyaedt.generic.clr_module import win32_client
 
@@ -423,7 +430,7 @@ class Desktop:
                 self._main.oDesktop = oAnsoftApp.GetAppDesktop()
                 self._main.isoutsideDesktop = True
         self._set_logger_file()
-        self._init_desktop()
+        self._init_desktop(non_graphical)
         self._logger.info("pyaedt v%s", self._main.pyaedt_version)
         if not settings.remote_api:
             self._logger.info("Python version %s", sys.version)
@@ -445,7 +452,7 @@ class Desktop:
         # Write the trace stack to the log file if an exception occurred in the main script.
         if ex_type:
             err = self._exception(ex_value, ex_traceback)
-        if self.close_on_exit:
+        if self.close_on_exit or not is_ironpython:
             self.release_desktop(close_projects=self.close_on_exit, close_on_exit=self.close_on_exit)
 
     @pyaedt_function_handler()
@@ -544,11 +551,15 @@ class Desktop:
                 return version_key
         return ""
 
-    def _init_desktop(self):
+    def _init_desktop(self, non_graphical):
         self._main.AEDTVersion = self._main.oDesktop.GetVersion()[0:6]
         self._main.oDesktop.RestoreWindow()
         self._main.sDesktopinstallDirectory = self._main.oDesktop.GetExeDir()
         self._main.pyaedt_initialized = True
+        try:
+            settings.enable_desktop_logs = not self._main.oDesktop.GetIsNonGraphical()
+        except AttributeError:
+            settings.enable_desktop_logs = not non_graphical
 
     def _set_version(self, specified_version, student_version):
         student_version_flag = False
@@ -596,8 +607,6 @@ class Desktop:
             oAnsoftApp = StandalonePyScriptWrapper.CreateObjectNew(non_graphical)
         else:
             oAnsoftApp = StandalonePyScriptWrapper.CreateObject(version)
-        if non_graphical:
-            settings.enable_desktop_logs = False
         self._main.oDesktop = oAnsoftApp.GetAppDesktop()
         self._main.isoutsideDesktop = True
         sys.path.append(os.path.join(base_path, "common", "commonfiles", "IronPython", "DLLs"))
@@ -656,8 +665,6 @@ class Desktop:
             StandalonePyScriptWrapper.CreateObjectNew(non_graphical)
         else:
             StandalonePyScriptWrapper.CreateObject(version)
-        if non_graphical:
-            settings.enable_desktop_logs = False
         processID2 = []
         if IsWindows:
             processID2 = com_active_sessions(version, student_version, non_graphical)
@@ -763,8 +770,6 @@ class Desktop:
             self._main.isoutsideDesktop = True
             self._main.oDesktop = self._main.oAnsoftApplication.GetAppDesktop()
             _proc = self._main.oDesktop.GetProcessID()
-            if non_graphical:
-                settings.enable_desktop_logs = False
             if new_aedt_session:
                 message = "{} {} version started with process ID {}.".format(
                     version, "Student" if student_version else "", _proc
