@@ -36,6 +36,7 @@ from pyaedt.edb_core.edb_data.sources import ExcitationProbes
 from pyaedt.edb_core.edb_data.sources import ExcitationSources
 from pyaedt.edb_core.edb_data.sources import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
+from pyaedt.edb_core.ipc2581.ipc2581 import Ipc2581
 from pyaedt.edb_core.materials import Materials
 from pyaedt.edb_core.padstack import EdbPadstacks
 from pyaedt.edb_core.stackup import Stackup
@@ -211,10 +212,11 @@ class Edb(object):
         self._db = None
         self._edb = None
         self.builder = None
-        self._edblib = None
         self.edbutils = None
         self.simSetup = None
         self.simsetupdata = None
+        self._setups = {}
+        self._layout_instance = None
         # time.sleep(2)
         # gc.collect()
 
@@ -258,10 +260,12 @@ class Edb(object):
     @pyaedt_function_handler()
     def _init_dlls(self):
         """Initialize DLLs."""
-        sys.path.append(os.path.join(os.path.dirname(__file__), "dlls", "EDBLib"))
         if os.name == "posix":
-            if env_value(self.edbversion) in os.environ:
-                self.base_path = env_path(self.edbversion)
+            if env_value(self.edbversion) in os.environ or settings.edb_dll_path:
+                if settings.edb_dll_path:
+                    self.base_path = settings.edb_dll_path
+                else:
+                    self.base_path = env_path(self.edbversion)
                 sys.path.append(self.base_path)
             else:
                 main = sys.modules["__main__"]
@@ -284,7 +288,9 @@ class Edb(object):
                 _clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
                 _clr.AddReference("Ansys.Ansoft.SimSetupData")
         else:
-            if self.student_version:
+            if settings.edb_dll_path:
+                self.base_path = settings.edb_dll_path
+            elif self.student_version:
                 self.base_path = env_path_student(self.edbversion)
             else:
                 self.base_path = env_path(self.edbversion)
@@ -299,29 +305,10 @@ class Edb(object):
         edb = __import__("Ansys.Ansoft.Edb")
         self.edb = edb.Ansoft.Edb
         edbbuilder = __import__("Ansys.Ansoft.EdbBuilderUtils")
-        self._edblib = None
         self.edbutils = edbbuilder.Ansoft.EdbBuilderUtils
         self.simSetup = __import__("Ansys.Ansoft.SimSetupData")
         self.simsetupdata = self.simSetup.Ansoft.SimSetupData.Data
 
-    @property
-    def edblib(self):
-        """EDB library object containing advanced EDB methods not accessible directly from Python."""
-        if not self._edblib:
-            if os.name == "posix" and is_ironpython:
-                _clr.AddReferenceToFile("EdbLib.dll")
-                _clr.AddReferenceToFile("DataModel.dll")
-            else:
-                _clr.AddReference("EdbLib")
-                _clr.AddReference("DataModel")
-            self._edblib = __import__("EdbLib")
-            dllpath = os.path.join(os.path.abspath(os.path.dirname(__file__)), "dlls", "EDBLib")
-            try:
-                self._edblib.Layout.LayoutMethods.LoadDataModel(dllpath, self.edbversion)
-            except:
-                pass
-        return self._edblib
-
     @property
     def excitations(self):
         """Get all layout excitations."""
@@ -335,6 +322,11 @@ class Edb(object):
                 temp[ter.GetName()] = ExcitationPorts(self, ter)
         return temp
 
+    @property
+    def excitations_nets(self):
+        """Get all excitations net names."""
+        return list(set([i.GetNet().GetName() for i in list(self._active_layout.Terminals)]))
+
     @property
     def sources(self):
         """Get all layout sources."""
@@ -390,8 +382,6 @@ class Edb(object):
             self._active_cell = list(self._db.TopCircuitCells)[0]
         self.logger.info("Cell %s Opened", self._active_cell.GetName())
         if self._db and self._active_cell:
-            dllpath = os.path.join(os.path.abspath(os.path.dirname(__file__)), "dlls", "EDBLib")
-            self.logger.info(dllpath)
             self.builder = EdbBuilder(self.edbutils, self._db, self._active_cell)
             self._init_objects()
             self.logger.info("Builder was initialized.")
@@ -473,7 +463,6 @@ class Edb(object):
         if not self.cellname:
             self.cellname = generate_unique_name("Cell")
         self._active_cell = self.edb.Cell.Cell.Create(self._db, self.edb.Cell.CellType.CircuitCell, self.cellname)
-        dllpath = os.path.join(os.path.dirname(__file__), "dlls", "EDBLib")
         if self._db and self._active_cell:
             self.builder = EdbBuilder(self.edbutils, self._db, self._active_cell)
             self._init_objects()
@@ -487,7 +476,7 @@ class Edb(object):
     ):
         """Import a board file and generate an ``edb.def`` file in the working directory.
 
-        This function supports all AEDT formats (DXF, GDS, SML (IPC2581), BRD, TGZ ...).
+        This function supports all AEDT formats, including DXF, GDS, SML (IPC2581), BRD, and TGZ.
 
         Parameters
         ----------
@@ -554,10 +543,12 @@ class Edb(object):
         self.open_edb()
 
     @pyaedt_function_handler()
-    def export_to_ipc2581(self, ipc_path=None, units="millimeter"):
+    def export_to_ipc2581(self, ipc_path=None, units="MILLIMETER"):
         """Create an XML IPC2581 file from the active EDB.
 
         .. note::
+           The method works only in CPython because of some limitations on Ironpython in XML parsing and
+           because it's time-consuming.
            This method is still being tested and may need further debugging.
            Any feedback is welcome. Backdrills and custom pads are not supported yet.
 
@@ -577,7 +568,10 @@ class Edb(object):
         bool
             ``True`` if successful, ``False`` if failed.
         """
-        if units.lower() not in ["millimeter", "inch", "micron"]:
+        if is_ironpython:  # pragma no cover
+            self.logger.error("This method is not supported in Ironpython")
+            return False
+        if units.lower() not in ["millimeter", "inch", "micron"]:  # pragma no cover
             self.logger.warning("The wrong unit is entered. Setting to the default, millimeter.")
             units = "millimeter"
 
@@ -585,19 +579,17 @@ class Edb(object):
             ipc_path = self.edbpath[:-4] + "xml"
         self.logger.info("Export IPC 2581 is starting. This operation can take a while.")
         start = time.time()
-        try:
-            result = self.edblib.IPC8521.IPCExporter.ExportIPC2581FromLayout(
-                self.active_layout, self.edbversion, ipc_path, units.lower()
-            )
-            end = time.time() - start
-            if result:
-                self.logger.info("Export IPC 2581 completed in %s sec.", end)
-                self.logger.info("File saved as %s", ipc_path)
-                return ipc_path
-        except Exception as e:
-            self.logger.info("Error exporting IPC 2581.")
-            self.logger.info(str(e))
-            return False
+        ipc = Ipc2581(self, units)
+        ipc.load_ipc_model()
+        ipc.file_path = ipc_path
+        result = ipc.write_xml()
+
+        if result:  # pragma no cover
+            self.logger.info_timer("Export IPC 2581 completed.", start)
+            self.logger.info("File saved as %s", ipc_path)
+            return ipc_path
+        self.logger.info("Error exporting IPC 2581.")
+        return False
 
     def edb_exception(self, ex_value, tb_data):
         """Write the trace stack to AEDT when a Python error occurs.
@@ -708,6 +700,13 @@ class Edb(object):
             self._active_layout = self.active_cell.GetLayout()
         return self._active_layout
 
+    @property
+    def layout_instance(self):
+        """Edb Layout Instance."""
+        if not self._layout_instance:
+            self._layout_instance = self.active_layout.GetLayoutInstance()
+        return self._layout_instance
+
     @property
     def pins(self):
         """EDBPadstackInstance of Component.
@@ -992,6 +991,7 @@ class Edb(object):
         else:
             return False
 
+    @pyaedt_function_handler()
     def _create_extent(
         self,
         net_signals,
@@ -1023,6 +1023,7 @@ class Edb(object):
                 _poly = self.edb.Geometry.PolygonData.GetConvexHullOfPolygons(_poly_list)
         return _poly
 
+    @pyaedt_function_handler()
     def _create_conformal(self, net_signals, expansion_size, tolerance, round_corner, round_extension):
         names = []
         _polys = []
@@ -1030,16 +1031,15 @@ class Edb(object):
             names.append(net.GetName())
         for prim in self.core_primitives.primitives:
             if prim.net_name in names:
-                _polys.extend(
-                    list(
-                        prim.primitive_object.GetPolygonData().Expand(
-                            expansion_size, tolerance, round_corner, round_extension
-                        )
-                    )
+                obj_data = prim.primitive_object.GetPolygonData().Expand(
+                    expansion_size, tolerance, round_corner, round_extension
                 )
+                if obj_data:
+                    _polys.extend(list(obj_data))
         _poly = self.edb.Geometry.PolygonData.Unite(convert_py_list_to_net_list(_polys))[0]
         return _poly
 
+    @pyaedt_function_handler()
     def _create_convex_hull(self, net_signals, expansion_size, tolerance, round_corner, round_extension):
         names = []
         _polys = []
@@ -1153,7 +1153,6 @@ class Edb(object):
                 self._db = db2
                 self.edbpath = output_aedb_path
                 self._active_cell = list(self._db.TopCircuitCells)[0]
-                dllpath = os.path.join(os.path.dirname(__file__), "dlls", "EDBLib")
                 self.builder = EdbBuilder(self.edbutils, self._db, self._active_cell)
                 self.edbpath = self._db.GetDirectory()
                 self._init_objects()
@@ -1258,25 +1257,32 @@ class Edb(object):
 
         if output_aedb_path:
             self.save_edb_as(output_aedb_path)
-
+        self.logger.info("Cutout Multithread started.")
         expansion_size = self.edb_value(expansion_size).ToDouble()
 
-        self.logger.reset_timer()
+        timer_start = self.logger.reset_timer()
         if custom_extent:
             reference_list = reference_list + signal_list
             all_list = reference_list
         else:
             all_list = signal_list + reference_list
-
-        for i in self.core_padstack.padstack_instances.values():
-            if i.net_name not in all_list:
-                i.delete()
-        for i in self.core_primitives.primitives:
-            if i.net_name not in all_list:
-                i.delete()
         for i in self.core_nets.nets.values():
             if i.name not in all_list:
                 i.net_object.Delete()
+        reference_pinsts = []
+        reference_prims = []
+        for i in self.core_padstack.padstack_instances.values():
+            net_name = i.net_name
+            if net_name not in all_list:
+                i.delete()
+            elif net_name in reference_list:
+                reference_pinsts.append(i)
+        for i in self.core_primitives.primitives:
+            net_name = i.net_name
+            if net_name not in all_list:
+                i.delete()
+            elif net_name in reference_list and not i.is_void:
+                reference_prims.append(i)
         self.logger.info_timer("Net clean up")
         self.logger.reset_timer()
 
@@ -1295,11 +1301,12 @@ class Edb(object):
             if extent_type in ["Conforming", self.edb.Geometry.ExtentType.Conforming, 1] and extent_defeature > 0:
                 _poly = _poly.Defeature(extent_defeature)
 
+        if not _poly or _poly.IsNull():
+            self._logger.error("Failed to create Extent.")
+            return False
         self.logger.info_timer("Expanded Net Polygon Creation")
         self.logger.reset_timer()
         _poly_list = convert_py_list_to_net_list([_poly])
-        polys = [i for i in self.core_primitives.primitives if not i.is_void]
-        pinsts = [i for i in list(self.core_padstack.padstack_instances.values())]
         prims_to_delete = []
         poly_to_create = []
         pins_to_delete = []
@@ -1314,52 +1321,49 @@ class Edb(object):
             return poly.Subtract(convert_py_list_to_net_list(poly), convert_py_list_to_net_list(voids))
 
         def clean_prim(prim_1):  # pragma: no cover
-            net = prim_1.net_name
-            if net in reference_list:
-                pdata = get_polygon_data(prim_1)
-                int_data = _poly.GetIntersectionType(pdata)
-                if int_data == 0:
-                    prims_to_delete.append(prim_1)
-                elif int_data != 2:
-                    list_poly = intersect(_poly, pdata)
-                    if list_poly:
-                        voids = prim_1.voids
-                        for p in list_poly:
-                            if p.IsNull():
-                                continue
-                            list_void = []
-                            void_to_subtract = []
-                            if voids:
-                                for void in voids:
-                                    void_pdata = get_polygon_data(void)
-                                    int_data2 = p.GetIntersectionType(void_pdata)
-                                    if int_data2 > 2:
-                                        void_to_subtract.append(void_pdata)
-                                    elif int_data2 == 2:
-                                        list_void.append(void_pdata)
-                                if void_to_subtract:
-                                    polys_cleans = subtract(p, void_to_subtract)
-                                    for polys_clean in polys_cleans:
-                                        if not polys_clean.IsNull():
-                                            void_to_append = [
-                                                v for v in list_void if polys_clean.GetIntersectionType(v) == 2
-                                            ]
-                                            poly_to_create.append([polys_clean, prim_1.layer_name, net, void_to_append])
-                                else:
-                                    poly_to_create.append([p, prim_1.layer_name, net, list_void])
+            pdata = get_polygon_data(prim_1)
+            int_data = _poly.GetIntersectionType(pdata)
+            if int_data == 0:
+                prims_to_delete.append(prim_1)
+            elif int_data != 2:
+                list_poly = intersect(_poly, pdata)
+                if list_poly:
+                    net = prim_1.net_name
+                    voids = prim_1.voids
+                    for p in list_poly:
+                        if p.IsNull():
+                            continue
+                        list_void = []
+                        void_to_subtract = []
+                        if voids:
+                            for void in voids:
+                                void_pdata = get_polygon_data(void)
+                                int_data2 = p.GetIntersectionType(void_pdata)
+                                if int_data2 > 2 or int_data2 == 1:
+                                    void_to_subtract.append(void_pdata)
+                                elif int_data2 == 2:
+                                    list_void.append(void_pdata)
+                            if void_to_subtract:
+                                polys_cleans = subtract(p, void_to_subtract)
+                                for polys_clean in polys_cleans:
+                                    if not polys_clean.IsNull():
+                                        void_to_append = [
+                                            v for v in list_void if polys_clean.GetIntersectionType(v) == 2
+                                        ]
+                                        poly_to_create.append([polys_clean, prim_1.layer_name, net, void_to_append])
                             else:
                                 poly_to_create.append([p, prim_1.layer_name, net, list_void])
+                        else:
+                            poly_to_create.append([p, prim_1.layer_name, net, list_void])
 
-                    prims_to_delete.append(prim_1)
+                prims_to_delete.append(prim_1)
 
         def pins_clean(pinst):
-            if pinst.net_name in reference_list and not pinst.in_polygon(_poly, simple_check=True):
+            if not pinst.in_polygon(_poly, simple_check=True):
                 pins_to_delete.append(pinst)
 
         with ThreadPoolExecutor(number_of_threads) as pool:
-            pool.map(lambda item: pins_clean(item), pinsts)
-        # for item in pinsts:
-        #     pins_clean(item)
+            pool.map(lambda item: pins_clean(item), reference_pinsts)
 
         for pin in pins_to_delete:
             pin.delete()
@@ -1368,7 +1372,7 @@ class Edb(object):
         self.logger.reset_timer()
 
         with ThreadPoolExecutor(number_of_threads) as pool:
-            pool.map(lambda item: clean_prim(item), polys)
+            pool.map(lambda item: clean_prim(item), reference_prims)
 
         for el in poly_to_create:
             self.core_primitives.create_polygon(el[0], el[1], net_name=el[2], voids=el[3])
@@ -1383,13 +1387,14 @@ class Edb(object):
             if val.numpins == 0:
                 val.edbcomponent.Delete()
                 i += 1
+        self.logger.info("Deleted {} additional components".format(i))
         if remove_single_pin_components:
             self.core_components.delete_single_pin_rlc()
+            self.logger.info_timer("Single Pins components deleted")
 
         self.core_components.refresh_components()
-        self.logger.info("Deleted {} additional components".format(i))
 
-        self.logger.info_timer("Single Pins components deleted")
+        self.logger.info_timer("Cutout completed.", timer_start)
         self.logger.reset_timer()
         return True
 
@@ -1405,9 +1410,8 @@ class Edb(object):
 
         Returns
         -------
-
-        Edb polygon object
-            Edb.Cell.Primitive.Polygon object
+        :class:`Edb.Cell.Primitive.Polygon`
+            Edb polygon object.
 
         """
         temp_edb_path = self.edbpath[:-5] + "_temp_aedb.aedb"
@@ -1557,13 +1561,13 @@ class Edb(object):
                 net = self.core_nets.find_or_create_net(p.net_name)
                 rotation = self.edb_value(p.rotation)
                 sign_layers = list(self.stackup.signal_layers.keys())
-                if not p.start_layer:
-                    fromlayer = self.stackup.signal_layers[sign_layers[-1]]._edb_layer
+                if not p.start_layer:  # pragma: no cover
+                    fromlayer = self.stackup.signal_layers[sign_layers[0]]._edb_layer
                 else:
                     fromlayer = self.stackup.signal_layers[p.start_layer]._edb_layer
 
-                if not p.stop_layer:
-                    tolayer = self.stackup.signal_layers[sign_layers[0]]._edb_layer
+                if not p.stop_layer:  # pragma: no cover
+                    tolayer = self.stackup.signal_layers[sign_layers[-1]]._edb_layer
                 else:
                     tolayer = self.stackup.signal_layers[p.stop_layer]._edb_layer
                 padstack = None
@@ -2113,6 +2117,8 @@ class Edb(object):
                         expansion_size=simulation_setup.cutout_subdesign_expansion,
                         use_round_corner=simulation_setup.cutout_subdesign_round_corner,
                         extent_type=simulation_setup.cutout_subdesign_type,
+                        use_pyaedt_extent_computing=True,
+                        remove_single_pin_components=True,
                     )
                     self.logger.info("Cutout processed.")
             self.logger.info("Deleting existing ports.")
@@ -2147,7 +2153,7 @@ class Edb(object):
                     self.core_components.create_port_on_component(
                         cmp,
                         net_list=simulation_setup.signal_nets,
-                        do_pingroup=True,
+                        do_pingroup=simulation_setup.do_pingroup,
                         reference_net=simulation_setup.power_nets,
                         port_type=SourceType.CircPort,
                     )
@@ -2159,6 +2165,7 @@ class Edb(object):
                 self.core_components.create_source_on_component(simulation_setup.sources)
                 if not self.core_siwave.configure_siw_analysis_setup(simulation_setup):  # pragma: no cover
                     self.logger.error("Failed to configure Siwave simulation setup.")
+            self.core_padstack.check_and_fix_via_plating()
             self.save_edb()
             if not simulation_setup.open_edb_after_build and simulation_setup.output_aedb:
                 self.close_edb()
@@ -2221,6 +2228,17 @@ class Edb(object):
 
     @pyaedt_function_handler()
     def new_simulation_configuration(self, filename=None):
+        """New SimulationConfiguration Object.
+
+        Parameters
+        ----------
+        filename : str, optional
+            Input config file.
+
+        Returns
+        -------
+        :class:`pyaedt.edb_core.edb_data.simulation_configuration.SimulationConfiguration`
+        """
         return SimulationConfiguration(filename, self)
 
     @property
@@ -2234,15 +2252,15 @@ class Edb(object):
         Dict[str, :class:`pyaedt.edb_core.edb_data.siwave_simulation_setup_data.SiwaveSYZSimulationSetup`]
 
         """
-        _setups = {}
         for i in list(self.active_cell.SimulationSetups):
-            if i.GetType() == self.edb.Utility.SimulationSetupType.kHFSS:
-                _setups[i.GetName()] = HfssSimulationSetup(self, i.GetName(), i)
-            elif i.GetType() == self.edb.Utility.SimulationSetupType.kSIWave:
-                _setups[i.GetName()] = SiwaveSYZSimulationSetup(self, i.GetName(), i)
-            elif i.GetType() == self.edb.Utility.SimulationSetupType.kSIWaveDCIR:
-                _setups[i.GetName()] = SiwaveDCSimulationSetup(self, i.GetName(), i)
-        return _setups
+            if i.GetName() not in self._setups:
+                if i.GetType() == self.edb.Utility.SimulationSetupType.kHFSS:
+                    self._setups[i.GetName()] = HfssSimulationSetup(self, i.GetName(), i)
+                elif i.GetType() == self.edb.Utility.SimulationSetupType.kSIWave:
+                    self._setups[i.GetName()] = SiwaveSYZSimulationSetup(self, i.GetName(), i)
+                elif i.GetType() == self.edb.Utility.SimulationSetupType.kSIWaveDCIR:
+                    self._setups[i.GetName()] = SiwaveDCSimulationSetup(self, i.GetName(), i)
+        return self._setups
 
     @property
     def hfss_setups(self):
@@ -2294,7 +2312,9 @@ class Edb(object):
         """
         if name in self.setups:
             return False
-        return HfssSimulationSetup(self, name)
+        setup = HfssSimulationSetup(self, name)
+        self._setups[name] = setup
+        return setup
 
     def create_siwave_syz_setup(self, name=None):
         """Create a setup from a template.
@@ -2317,9 +2337,13 @@ class Edb(object):
         ...                           ["linear scale", "0.1GHz", "10GHz", "0.1GHz"],
         ...                           ])
         """
+        if not name:
+            name = generate_unique_name("Siwave_SYZ")
         if name in self.setups:
             return False
-        return SiwaveSYZSimulationSetup(self, name)
+        setup = SiwaveSYZSimulationSetup(self, name)
+        self._setups[name] = setup
+        return setup
 
     def create_siwave_dc_setup(self, name=None):
         """Create a setup from a template.
@@ -2339,6 +2363,10 @@ class Edb(object):
         >>> setup1.mesh_bondwires = True
 
         """
+        if not name:
+            name = generate_unique_name("Siwave_DC")
         if name in self.setups:
             return False
-        return SiwaveDCSimulationSetup(self, name)
+        setup = SiwaveDCSimulationSetup(self, name)
+        self._setups[name] = setup
+        return setup
