@@ -7,7 +7,6 @@ import math
 import re
 
 from pyaedt import _retry_ntimes
-from pyaedt import generate_unique_name
 from pyaedt.edb_core.edb_data.components_data import EDBComponent
 from pyaedt.edb_core.edb_data.components_data import EDBComponentDef
 from pyaedt.edb_core.edb_data.padstacks_data import EDBPadstackInstance
@@ -20,7 +19,7 @@ from pyaedt.generic.clr_module import _clr
 from pyaedt.generic.general_methods import get_filename_without_extension
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.modeler.geometry_operators import GeometryOperators
 
 
 def resistor_value_parser(RValue):
@@ -735,8 +734,8 @@ class Components(object):
         >>> port_type=SourceType.CoaxPort, do_pingroup=False, refnet="GND")
 
         """
-        if isinstance(component, self._edb.Cell.Hierarchy.Component):
-            cmp = component.GetName()
+        if isinstance(component, str):
+            component = self.components[component].edbcomponent
         if not isinstance(net_list, list):
             net_list = [net_list]
         for net in net_list:
@@ -749,11 +748,18 @@ class Components(object):
                     pass
         if reference_net in net_list:
             net_list.remove(reference_net)
-        cmp_pins = self.get_pin_from_component(component, net_list)
+        cmp_pins = [
+            p for p in list(component.LayoutObjs) if int(p.GetObjType()) == 1 and p.GetNet().GetName() in net_list
+        ]
+        for p in cmp_pins:  # pragma no cover
+            if not p.IsLayoutPin():
+                p.SetIsLayoutPin(True)
         if len(cmp_pins) == 0:
+            self._logger.info(
+                "No pins found on component {}, searching padstack instances instead".format(component.GetName())
+            )
             return False
         pin_layers = cmp_pins[0].GetPadstackDef().GetData().GetLayerNames()
-
         if port_type == SourceType.CoaxPort:
             pad_params = self._padstack.get_pad_parameters(pin=cmp_pins[0], layername=pin_layers[0], pad_type=0)
             sball_diam = min([self._pedb.edb_value(val).ToDouble() for val in pad_params[1]])
@@ -762,8 +768,17 @@ class Components(object):
             for pin in cmp_pins:
                 self._padstack.create_coax_port(pin)
 
-        elif port_type == SourceType.CircPort:
-            ref_pins = self.get_pin_from_component(component, reference_net)
+        elif port_type == SourceType.CircPort:  # pragma no cover
+            ref_pins = [
+                p
+                for p in list(component.LayoutObjs)
+                if int(p.GetObjType()) == 1 and p.GetNet().GetName() in reference_net
+            ]
+            for p in ref_pins:
+                if not p.IsLayoutPin():
+                    p.SetIsLayoutPin(True)
+            if len(ref_pins) == 0:
+                self._logger.info("No reference pin found on component {}.".format(component.GetName()))
             if do_pingroup:
                 if len(ref_pins) == 1:
                     self.create_terminal = self._create_terminal(ref_pins[0])
@@ -789,8 +804,12 @@ class Components(object):
                         self._logger.info("No pins found on component {} for the net {}".format(component, net))
 
             else:
+                ref_pin_group = self.create_pingroup_from_pins(ref_pins)
+                if not ref_pin_group:
+                    self._logger.warning("failed to create reference pin group")
+                    return False
                 for net in net_list:
-                    pins = [pin for pin in cmp_pins if pin.GetNet().GetName().lower() == net]
+                    pins = [pin for pin in cmp_pins if pin.GetNet().GetName() == net]
                     for pin in pins:
                         ref_pin = self._get_closest_pin_from(pin, ref_pins)
                         ref_pin_term = self._create_terminal(ref_pin)
@@ -984,11 +1003,11 @@ class Components(object):
         else:
             cmp_name = pingroup.GetComponent().GetName()
         net_name = pingroup.GetNet().GetName()
+        pin_name = list(pingroup.GetPins())[0].GetName()  # taking first pin name as convention.
         if cmp_name:
-            term_name = generate_unique_name("{0}.{1}.Pingroup".format(cmp_name, net_name), n=2)
+            term_name = "{0}.{1}.{2}".format(net_name, cmp_name, pin_name)
         else:
-            term_name = generate_unique_name("{0}.Pingroup".format(net_name), n=2)
-
+            term_name = "{0}.{1}".format(net_name, pin_name)
         pingroup_term = self._edb.Cell.Terminal.PinGroupTerminal.Create(
             self._active_layout, pingroup.GetNet(), term_name, pingroup, isref
         )
@@ -1279,7 +1298,7 @@ class Components(object):
         Returns
         -------
         tuple
-            (bool, pingroup)
+            The tuple is structured as: (bool, pingroup).
 
         Examples
         --------
@@ -2180,9 +2199,8 @@ class Components(object):
 
             trace_points.append(positions_to_short[i + 1])
 
-            path = self._pedb.core_primitives.Shape("polygon", points=trace_points)
-            self._pedb.core_primitives.create_path(
-                path,
+            self._pedb.core_primitives.create_trace(
+                trace_points,
                 layer_name=placement_layer,
                 net_name="short",
                 width=w,
