@@ -124,9 +124,9 @@ class EdbFrequencySweep(object):
     def freq_sweep_type(self):
         """Sweep type.
         Options are:
-           - ``kInterpolatingSweep``.
-           - ``kDiscreteSweep``.
-           - ``kBroadbandFastSweep``.
+        - ``kInterpolatingSweep``.
+        - ``kDiscreteSweep``.
+        - ``kBroadbandFastSweep``.
 
         Returns
         -------
@@ -391,9 +391,6 @@ class EdbFrequencySweep(object):
             ``True`` if correctly executed, ``False`` otherwise.
 
         """
-        start = self._sim_setup._edb.arg_to_dim(start, "Hz")
-        stop = self._sim_setup._edb.arg_to_dim(stop, "Hz")
-        step = self._sim_setup._edb.arg_to_dim(step, "Hz")
         self._edb_sweep_data.Frequencies = self._edb_sweep_data.SetFrequencies(start, stop, step)
         return self._update_sweep()
 
@@ -848,20 +845,22 @@ class HfssSolverSettings(object):
     @property
     def order_basis(self):
         """Order of the basic functions for HFSS.
-        - 0=Mixed.
-        - 1=Zero.
-        - 2=1st order.
-        - 3=2nd order.
+        - 0=Zero.
+        - 1=1st order.
+        - 2=2nd order.
+        - 3=Mixed.
 
         Returns
         -------
         int
             Integer value according to the description."""
-        return self._hfss_solver_settings.OrderBasis
+        mapping = {0: "zero", 1: "first", 2: "second", 3: "mixed"}
+        return mapping[self._hfss_solver_settings.OrderBasis]
 
     @order_basis.setter
     def order_basis(self, value):
-        self._hfss_solver_settings.OrderBasis = value
+        mapping = {"zero": 0, "first": 1, "second": 2, "mixed": 3}
+        self._hfss_solver_settings.OrderBasis = mapping[value]
         self._parent._update_setup()
 
     @property
@@ -892,7 +891,19 @@ class HfssSolverSettings(object):
         -------
         str
         """
-        return self._hfss_solver_settings.SolverType.ToString()
+        mapping = {"kAutoSolver": "auto", "kDirectSolver": "direct", "kIterativeSolver": "iterative"}
+        solver_type = self._hfss_solver_settings.SolverType.ToString()
+        return mapping[solver_type]
+
+    @solver_type.setter
+    def solver_type(self, value):
+        mapping = {
+            "auto": self._hfss_solver_settings.SolverType.kAutoSolver,
+            "direct": self._hfss_solver_settings.SolverType.kDirectSolver,
+            "iterative": self._hfss_solver_settings.SolverType.kIterativeSolver,
+        }
+        self._hfss_solver_settings.SolverType = mapping[value]
+        self._parent._update_setup()
 
     @property
     def use_shell_elements(self):
@@ -976,7 +987,12 @@ class AdaptiveSettings(object):
 
     @property
     def adaptive_settings(self):
-        """Adaptive EDB settings."""
+        """Adaptive EDB settings.
+
+        Returns
+        -------
+        :class:`pyaedt.edb_core.edb_data.hfss_simulation_setup_data.AdaptiveSettings`
+        """
         return self._parent._edb_sim_setup_info.SimulationSettings.AdaptiveSettings
 
     @property
@@ -993,10 +1009,10 @@ class AdaptiveSettings(object):
     def adapt_type(self):
         """Adaptive type.
         Options:
-         1- ``kSingle``.
-         2- ``kMultiFrequencies``.
-         3- ``kBroadband``.
-         4- ``kNumAdaptTypes``.
+        1- ``kSingle``.
+        2- ``kMultiFrequencies``.
+        3- ``kBroadband``.
+        4- ``kNumAdaptTypes``.
 
         Returns
         -------
@@ -1148,7 +1164,7 @@ class AdaptiveSettings(object):
         self._parent._update_setup()
 
     @pyaedt_function_handler()
-    def add_adaptive_frequency_data(self, frequency, max_num_passes=10, max_delta_s=0.02):
+    def add_adaptive_frequency_data(self, frequency=0, max_num_passes=10, max_delta_s=0.02):
         """Add a setup for frequency data.
 
         Parameters
@@ -1165,12 +1181,50 @@ class AdaptiveSettings(object):
         bool
             ``True`` if method is successful, ``False`` otherwise.
         """
-        adaptive_frequency_data = self._parent._edb.simsetupdata.AdaptiveFrequencyData()
-        data = AdaptiveFrequencyData(adaptive_frequency_data)
-        data.adaptive_frequency = self._parent._edb.arg_with_dim(frequency, "Hz")
-        data.max_passes = max_num_passes
-        data.max_delta = str(max_delta_s)
-        self.adaptive_settings.AdaptiveFrequencyDataList.Add(data._adaptive_frequency_data)
+        low_freq_adapt_data = self._parent._edb.simsetupdata.AdaptiveFrequencyData()
+        low_freq_adapt_data.MaxDelta = self._parent._edb.edb_value(max_delta_s).ToString()
+        low_freq_adapt_data.MaxPasses = max_num_passes
+        low_freq_adapt_data.AdaptiveFrequency = self._parent._edb.edb_value(frequency).ToString()
+        high_freq_adapt_data = self._parent._edb.simsetupdata.AdaptiveFrequencyData()
+        high_freq_adapt_data.MaxDelta = self._parent._edb.edb_value(max_delta_s).ToString()
+        high_freq_adapt_data.MaxPasses = max_num_passes
+        high_freq_adapt_data.AdaptiveFrequency = self._parent._edb.edb_value(frequency).ToString()
+        self.adaptive_settings.AdaptiveFrequencyDataList.Add(low_freq_adapt_data)
+        self.adaptive_settings.AdaptiveFrequencyDataList.Add(high_freq_adapt_data)
+        return self._parent._update_setup()
+
+    @pyaedt_function_handler()
+    def add_broadband_adaptive_frequency_data(
+        self, low_frequency=0, high_frequency=10e9, max_num_passes=10, max_delta_s=0.02
+    ):
+        """Add a setup for frequency data.
+
+        Parameters
+        ----------
+        low_frequency : str, float
+            Frequency with units or float frequency (in Hz).
+        high_frequency : str, float
+            Frequency with units or float frequency (in Hz).
+        max_num_passes : int, optional
+            Maximum number of passes. The default is ``10``.
+        max_delta_s : float, optional
+            Maximum delta S. The default is ``0.02``.
+
+        Returns
+        -------
+        bool
+            ``True`` if method is successful, ``False`` otherwise.
+        """
+        low_freq_adapt_data = self._parent._edb.simsetupdata.AdaptiveFrequencyData()
+        low_freq_adapt_data.MaxDelta = self._parent._edb.edb_value(max_delta_s).ToString()
+        low_freq_adapt_data.MaxPasses = max_num_passes
+        low_freq_adapt_data.AdaptiveFrequency = self._parent._edb.edb_value(low_frequency).ToString()
+        high_freq_adapt_data = self._parent._edb.simsetupdata.AdaptiveFrequencyData()
+        high_freq_adapt_data.MaxDelta = self._parent._edb.edb_value(max_delta_s).ToString()
+        high_freq_adapt_data.MaxPasses = max_num_passes
+        high_freq_adapt_data.AdaptiveFrequency = self._parent._edb.edb_value(high_frequency).ToString()
+        self.adaptive_settings.AdaptiveFrequencyDataList.Add(low_freq_adapt_data)
+        self.adaptive_settings.AdaptiveFrequencyDataList.Add(high_freq_adapt_data)
         return self._parent._update_setup()
 
 
@@ -1217,14 +1271,13 @@ class DefeatureSettings(object):
     @property
     def healing_option(self):
         """Whether to turn on healing of mis-aligned points and edges.
-        Options:
-          0- Turn off.
-          1- Turn on.
+        Options are:
+        0- Turn off.
+        1- Turn on.
 
         Returns
         -------
         int
-
         """
         return self._defeature_settings.HealingOption
 
@@ -1672,7 +1725,7 @@ class HfssSimulationSetup(object):
             else:
                 self._edb_sim_setup_info.Name = name
             self._name = name
-            self.hfss_solver_settings.order_basis = 0
+            self.hfss_solver_settings.order_basis = "mixed"
 
             self._edb_sim_setup = self._edb.edb.Utility.HFSSSimulationSetup(self._edb_sim_setup_info)
             self._update_setup()
@@ -1721,18 +1774,21 @@ class HfssSimulationSetup(object):
 
     @name.setter
     def name(self, value):
+        legacy_name = self._name
         self._edb_sim_setup_info.Name = value
         self._update_setup()
+        if legacy_name in self._edb.setups:
+            del self._edb._setups[legacy_name]
         self._name = value
 
     @property
     def solver_slider_type(self):
         """Solver slider type.
-        Options:
-         1- ``kFast``.
-         2- ``kMedium``.
-         3- ``kAccurate``.
-         4- ``kNumSliderTypes``.
+        Options are:
+        1 - ``kFast``.
+        2 - ``kMedium``.
+        3 - ``kAccurate``.
+        4 - ``kNumSliderTypes``.
 
         Returns
         -------
@@ -1993,10 +2049,20 @@ class HfssSimulationSetup(object):
         name : str, optional
             Name of the frequency sweep.
         frequency_sweep : list, optional
+            List of frequency points.
 
         Returns
-        ----------
-        :class:`pyaedt.edb_core.edb_data.hfss_simulation_setup_data.EdbFrequencySweep
+        -------
+        :class:`pyaedt.edb_core.edb_data.hfss_simulation_setup_data.EdbFrequencySweep`
+
+        Examples
+        --------
+        >>> setup1 = edbapp.create_hfss_setup("setup1")
+        >>> setup1.add_frequency_sweep(frequency_sweep=[
+        ...                           ["linear count", "0", "1kHz", 1],
+        ...                           ["log scale", "1kHz", "0.1GHz", 10],
+        ...                           ["linear scale", "0.1GHz", "10GHz", "0.1GHz"],
+        ...                           ])
         """
         if name in self.frequency_sweeps:
             return False
@@ -2022,8 +2088,8 @@ class HfssSimulationSetup(object):
         bool
 
         """
-        self.adaptive_settings.adaptive_settings.AdaptiveFrequencyDataList.Clear()
         self.adaptive_settings.adapt_type = "kSingle"
+        self.adaptive_settings.adaptive_settings.AdaptiveFrequencyDataList.Clear()
         return self.adaptive_settings.add_adaptive_frequency_data(frequency, max_num_passes, max_delta_s)
 
     @pyaedt_function_handler()
@@ -2074,8 +2140,8 @@ class HfssSimulationSetup(object):
         """
         self.adaptive_settings.adapt_type = "kBroadband"
         self.adaptive_settings.adaptive_settings.AdaptiveFrequencyDataList.Clear()
-        if not self.adaptive_settings.add_adaptive_frequency_data(low_frequency, max_num_passes, max_delta_s):
-            return False
-        if not self.adaptive_settings.add_adaptive_frequency_data(high_frequency, max_num_passes, max_delta_s):
+        if not self.adaptive_settings.add_broadband_adaptive_frequency_data(
+            low_frequency, high_frequency, max_num_passes, max_delta_s
+        ):  # pragma no cover
             return False
         return True
