@@ -568,7 +568,7 @@ class EDBLayer(object):
         Returns
         -------
         type
-            Layer
+            The layer which was updated.
 
         """
 
@@ -1152,7 +1152,7 @@ class EDBLayers(object):
         Returns
         -------
         bool
-            "True" if succeeded
+            "True" if succeeded.
         """
         outlineLayer = self._edb.Cell.Layer.FindByName(self._active_layout.GetLayerCollection(), outline_name)
         if outlineLayer.IsNull():
@@ -1203,11 +1203,60 @@ class EDBLayers(object):
 
 
 class LayerEdbClass(object):
-    """New Edb Layer management class. Replaces EDBLayer."""
+    """Manages Edb Layers. Replaces EDBLayer."""
 
     def __init__(self, pclass, name):
         self._pclass = pclass
         self._name = name
+        self._color = ()
+        self._type = ""
+        self._material = ""
+        self._conductivity = 0.0
+        self._permittivity = 0.0
+        self._loss_tangent = 0.0
+        self._dielectric_fill = ""
+        self._thickness = 0.0
+        self._etch_factor = 0.0
+        self._roughness_enabled = False
+        self._top_hallhuray_nodule_radius = 0.5e-6
+        self._top_hallhuray_surface_ratio = 2.9
+        self._bottom_hallhuray_nodule_radius = 0.5e-6
+        self._bottom_hallhuray_surface_ratio = 2.9
+        self._side_hallhuray_nodule_radius = 0.5e-6
+        self._side_hallhuray_surface_ratio = 2.9
+        self._material = None
+        self._upper_elevation = 0.0
+        self._lower_elevation = 0.0
+
+    @property
+    def lower_elevation(self):
+        """Lower elevation.
+
+        Returns
+        -------
+        float
+            Lower elevation.
+        """
+        try:
+            self._lower_elevation = self._edb_layer.GetLowerElevation()
+        except:
+            pass
+        return self._lower_elevation
+
+    @property
+    def upper_elevation(self):
+        """Upper elevation.
+
+        Returns
+        -------
+        float
+            Upper elevation.
+        """
+        try:
+            self._upper_elevation = self._edb_layer.GetUpperElevation()
+        except:
+            pass
+        return self._upper_elevation
 
     @property
     def _edb(self):
@@ -1247,6 +1296,24 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetColor(*rgb)
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._color = rgb
+
+    @property
+    def transparency(self):
+        """Retrieve transparency of the layer.
+
+        Returns
+        -------
+        int
+            An integer between 0 and 100 with 0 being fully opaque and 100 being fully transparent.
+        """
+        return self._edb_layer.GetTransparency()
+
+    @transparency.setter
+    def transparency(self, trans):
+        layer_clone = self._edb_layer
+        layer_clone.SetTransparency(trans)
+        self._pclass._set_layout_stackup(layer_clone, "change_attribute")
 
     @property
     def name(self):
@@ -1281,8 +1348,10 @@ class LayerEdbClass(object):
             return
         if new_type == "signal":
             self._edb_layer.SetLayerType(self._edb.Cell.LayerType.SignalLayer)
+            self._type = new_type
         elif new_type == "dielectric":
             self._edb_layer.SetLayerType(self._edb.Cell.LayerType.DielectricLayer)
+            self._type = new_type
         else:
             return
 
@@ -1301,6 +1370,7 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetMaterial(name)
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._material = name
 
     @property
     def conductivity(self):
@@ -1311,7 +1381,9 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].conductivity
+            self._conductivity = self._pclass._pedb.materials[self.material].conductivity
+            return self._conductivity
+
         return None
 
     @property
@@ -1323,7 +1395,8 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].permittivity
+            self._permittivity = self._pclass._pedb.materials[self.material].permittivity
+            return self._permittivity
         return None
 
     @property
@@ -1335,14 +1408,16 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].loss_tangent
+            self._loss_tangent = self._pclass._pedb.materials[self.material].loss_tangent
+            return self._loss_tangent
         return None
 
     @property
     def dielectric_fill(self):
         """Retrieve material name of the layer dielectric fill."""
         if self.type == "signal":
-            return self._edb_layer.GetFillMaterial()
+            self._dielectric_fill = self._edb_layer.GetFillMaterial()
+            return self._dielectric_fill
         else:
             return
 
@@ -1352,6 +1427,7 @@ class LayerEdbClass(object):
             layer_clone = self._edb_layer
             layer_clone.SetFillMaterial(name)
             self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+            self._dielectric_fill = name
         else:
             pass
 
@@ -1365,7 +1441,8 @@ class LayerEdbClass(object):
         """
         if not self.is_stackup_layer:  # pragma: no cover
             return
-        return self._edb_layer.GetThicknessValue().ToDouble()
+        self._thickness = self._edb_layer.GetThicknessValue().ToDouble()
+        return self._thickness
 
     @thickness.setter
     def thickness(self, value):
@@ -1374,6 +1451,7 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetThickness(self._pclass._edb_value(value))
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._thickness = value
 
     @property
     def etch_factor(self):
@@ -1383,7 +1461,8 @@ class LayerEdbClass(object):
         -------
         float
         """
-        return self._edb_layer.GetEtchFactor().ToDouble()
+        self._etch_factor = self._edb_layer.GetEtchFactor().ToDouble()
+        return self._etch_factor
 
     @etch_factor.setter
     def etch_factor(self, value):
@@ -1397,6 +1476,7 @@ class LayerEdbClass(object):
             layer_clone.SetEtchFactorEnabled(True)
             layer_clone.SetEtchFactor(self._pclass._edb_value(value))
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._etch_factor = value
 
     @property
     def roughness_enabled(self):
@@ -1408,12 +1488,14 @@ class LayerEdbClass(object):
         """
         if not self.is_stackup_layer:  # pragma: no cover
             return
-        return self._edb_layer.IsRoughnessEnabled()
+        self._roughness_enabled = self._edb_layer.IsRoughnessEnabled()
+        return self._roughness_enabled
 
     @roughness_enabled.setter
     def roughness_enabled(self, set_enable):
         if not self.is_stackup_layer:  # pragma: no cover
             return
+        self._roughness_enabled = set_enable
         if set_enable:
             layer_clone = self._edb_layer
             layer_clone.SetRoughnessEnabled(True)
@@ -1424,6 +1506,101 @@ class LayerEdbClass(object):
             layer_clone.SetRoughnessEnabled(False)
             self._pclass._set_layout_stackup(layer_clone, "change_attribute")
 
+    @property
+    def top_hallhuray_nodule_radius(self):
+        """Retrieve huray model nodule radius on top of the conductor."""
+        top_roughness_model = self.get_roughness_model("top")
+        if top_roughness_model:
+            self._top_hallhuray_nodule_radius = top_roughness_model.NoduleRadius.ToDouble()
+        return self._top_hallhuray_nodule_radius
+
+    @top_hallhuray_nodule_radius.setter
+    def top_hallhuray_nodule_radius(self, value):
+        self._top_hallhuray_nodule_radius = value
+
+    @property
+    def top_hallhuray_surface_ratio(self):
+        """Retrieve huray model surface ratio on top of the conductor."""
+        top_roughness_model = self.get_roughness_model("top")
+        if top_roughness_model:
+            self._top_hallhuray_surface_ratio = top_roughness_model.SurfaceRatio.ToDouble()
+        return self._top_hallhuray_surface_ratio
+
+    @top_hallhuray_surface_ratio.setter
+    def top_hallhuray_surface_ratio(self, value):
+        self._top_hallhuray_surface_ratio = value
+
+    @property
+    def bottom_hallhuray_nodule_radius(self):
+        """Retrieve huray model nodule radius on bottom of the conductor."""
+        bottom_roughness_model = self.get_roughness_model("bottom")
+        if bottom_roughness_model:
+            self._bottom_hallhuray_nodule_radius = bottom_roughness_model.NoduleRadius.ToDouble()
+        return self._bottom_hallhuray_nodule_radius
+
+    @bottom_hallhuray_nodule_radius.setter
+    def bottom_hallhuray_nodule_radius(self, value):
+        self._bottom_hallhuray_nodule_radius = value
+
+    @property
+    def bottom_hallhuray_surface_ratio(self):
+        """Retrieve huray model surface ratio on bottom of the conductor."""
+        bottom_roughness_model = self.get_roughness_model("bottom")
+        if bottom_roughness_model:
+            self._bottom_hallhuray_surface_ratio = bottom_roughness_model.SurfaceRatio.ToDouble()
+        return self._bottom_hallhuray_surface_ratio
+
+    @bottom_hallhuray_surface_ratio.setter
+    def bottom_hallhuray_surface_ratio(self, value):
+        self._bottom_hallhuray_surface_ratio = value
+
+    @property
+    def side_hallhuray_nodule_radius(self):
+        """Retrieve huray model nodule radius on sides of the conductor."""
+        side_roughness_model = self.get_roughness_model("side")
+        if side_roughness_model:
+            self._side_hallhuray_nodule_radius = side_roughness_model.NoduleRadius.ToDouble()
+        return self._side_hallhuray_nodule_radius
+
+    @side_hallhuray_nodule_radius.setter
+    def side_hallhuray_nodule_radius(self, value):
+        self._side_hallhuray_nodule_radius = value
+
+    @property
+    def side_hallhuray_surface_ratio(self):
+        """Retrieve huray model surface ratio on sides of the conductor."""
+        side_roughness_model = self.get_roughness_model("side")
+        if side_roughness_model:
+            self._side_hallhuray_surface_ratio = side_roughness_model.SurfaceRatio.ToDouble()
+        return self._side_hallhuray_surface_ratio
+
+    @side_hallhuray_surface_ratio.setter
+    def side_hallhuray_surface_ratio(self, value):
+        self._side_hallhuray_surface_ratio = value
+
+    @pyaedt_function_handler()
+    def get_roughness_model(self, surface="top"):
+        """Get roughness model of the layer.
+
+        Parameters
+        ----------
+        surface : str, optional
+            Where to fetch roughness model. The default is ``"top"``. Options are ``"top"``, ``"bottom"``, ``"side"``.
+
+        Returns
+        -------
+        ``"Ansys.Ansoft.Edb.Cell.RoughnessModel"``
+
+        """
+        if not self.is_stackup_layer:  # pragma: no cover
+            return
+        if surface == "top":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top)
+        elif surface == "bottom":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom)
+        elif surface == "side":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side)
+
     @pyaedt_function_handler()
     def assign_roughness_model(
         self,
@@ -1439,7 +1616,7 @@ class LayerEdbClass(object):
         ----------
         model_type : str, optional
             Type of roughness model. The default is ``"huray"``. Options are ``"huray"``, ``"groisse"``.
-        huray_radius : str, optional
+        huray_radius : str, float, optional
             Radius of huray model. The default is ``"0.5um"``.
         huray_surface_ratio : str, float, optional.
             Surface ratio of huray model. The default is ``"2.9"``.
@@ -1455,27 +1632,27 @@ class LayerEdbClass(object):
         if not self.is_stackup_layer:  # pragma: no cover
             return
         radius = self._pclass._edb_value(huray_radius)
+        self._hurray_nodule_radius = huray_radius
         surface_ratio = self._pclass._edb_value(huray_surface_ratio)
+        self._hurray_surface_ratio = huray_surface_ratio
         groisse_roughness = self._pclass._edb_value(groisse_roughness)
         regions = []
         if apply_on_surface == "all":
+            self._side_roughness = "all"
             regions = [
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top,
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side,
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom,
             ]
         elif apply_on_surface == "top":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top,
-            ]
+            self._side_roughness = "top"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top]
         elif apply_on_surface == "bottom":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom,
-            ]
+            self._side_roughness = "bottom"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom]
         elif apply_on_surface == "side":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side,
-            ]
+            self._side_roughness = "side"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side]
 
         layer_clone = self._edb_layer
         for r in regions:
@@ -1485,3 +1662,75 @@ class LayerEdbClass(object):
                 model = self._pclass._pedb.edb.Cell.GroisseRoughnessModel(groisse_roughness)
             layer_clone.SetRoughnessModel(r, model)
         return self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+
+    @pyaedt_function_handler()
+    def _json_format(self):
+        dict_out = {}
+        self._color = self.color
+        self._dielectric_fill = self.dielectric_fill
+        self._etch_factor = self.etch_factor
+        self._material = self.material
+        self._name = self.name
+        self._roughness_enabled = self.roughness_enabled
+        self._thickness = self.thickness
+        self._type = self.type
+        self._roughness_enabled = self.roughness_enabled
+        self._top_hallhuray_nodule_radius = self.top_hallhuray_nodule_radius
+        self._top_hallhuray_surface_ratio = self.top_hallhuray_surface_ratio
+        self._side_hallhuray_nodule_radius = self.side_hallhuray_nodule_radius
+        self._side_hallhuray_surface_ratio = self.side_hallhuray_surface_ratio
+        self._bottom_hallhuray_nodule_radius = self.bottom_hallhuray_nodule_radius
+        self._bottom_hallhuray_surface_ratio = self.bottom_hallhuray_surface_ratio
+        for k, v in self.__dict__.items():
+            if (
+                not k == "_pclass"
+                and not k == "_conductivity"
+                and not k == "_permittivity"
+                and not k == "_loss_tangent"
+            ):
+                dict_out[k[1:]] = v
+        return dict_out
+
+    def _load_layer(self, layer):
+        if layer:
+            self.color = layer["color"]
+            self.type = layer["type"]
+            if isinstance(layer["material"], str):
+                self.material = layer["material"]
+            else:
+                self._pclass._pedb.materials._load_materials(layer["material"])
+                self.material = layer["material"]["name"]
+            if layer["dielectric_fill"]:
+                if isinstance(layer["dielectric_fill"], str):
+                    self.dielectric_fill = layer["dielectric_fill"]
+                else:
+                    self._pclass._pedb.materials._load_materials(layer["dielectric_fill"])
+                    self.dielectric_fill = layer["dielectric_fill"]["name"]
+            self.thickness = layer["thickness"]
+            self.etch_factor = layer["etch_factor"]
+            self.roughness_enabled = layer["roughness_enabled"]
+            if self.roughness_enabled:
+                self.top_hallhuray_nodule_radius = layer["top_hallhuray_nodule_radius"]
+                self.top_hallhuray_surface_ratio = layer["top_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["top_hallhuray_nodule_radius"],
+                    layer["top_hallhuray_surface_ratio"],
+                    apply_on_surface="top",
+                )
+                self.bottom_hallhuray_nodule_radius = layer["bottom_hallhuray_nodule_radius"]
+                self.bottom_hallhuray_surface_ratio = layer["bottom_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["bottom_hallhuray_nodule_radius"],
+                    layer["bottom_hallhuray_surface_ratio"],
+                    apply_on_surface="bottom",
+                )
+                self.side_hallhuray_nodule_radius = layer["side_hallhuray_nodule_radius"]
+                self.side_hallhuray_surface_ratio = layer["side_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["side_hallhuray_nodule_radius"],
+                    layer["side_hallhuray_surface_ratio"],
+                    apply_on_surface="side",
+                )
