@@ -7,7 +7,7 @@ from pyaedt.generic.clr_module import String
 from pyaedt.generic.clr_module import _clr
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.modeler.geometry_operators import GeometryOperators
 
 
 class EDBPadProperties(object):
@@ -36,6 +36,7 @@ class EDBPadProperties(object):
         self._pedbpadstack = p_edb_padstack
         self.layer_name = layer_name
         self.pad_type = pad_type
+        self._parameters_values = None
         pass
 
     @property
@@ -103,11 +104,12 @@ class EDBPadProperties(object):
         list
             List of parameters.
         """
-
+        self._parameters_values = []
         pad_values = self._edb_padstack.GetData().GetPadParametersValue(
             self.layer_name, self.int_to_pad_type(self.pad_type)
         )
-        return [i.ToDouble() for i in pad_values[2]]
+        self._parameters_values = [i.ToDouble() for i in pad_values[2]]
+        return self._parameters_values
 
     @property
     def polygon_data(self):
@@ -329,6 +331,7 @@ class EDBPadstack(object):
         self.antipad_by_layer = {}
         self.thermalpad_by_layer = {}
         self._bounding_box = []
+        self._hole_params = None
         for layer in self.via_layers:
             self.pad_by_layer[layer] = EDBPadProperties(edb_padstack, layer, 0, self)
             self.antipad_by_layer[layer] = EDBPadProperties(edb_padstack, layer, 1, self)
@@ -393,10 +396,12 @@ class EDBPadstack(object):
         return list(self.via_layers)[-1]
 
     @property
-    def _hole_params(self):
+    def hole_params(self):
+        """Via Hole parameters values."""
+
         viaData = self.edb_padstack.GetData()
-        out = viaData.GetHoleParametersValue()
-        return out
+        self._hole_params = viaData.GetHoleParametersValue()
+        return self._hole_params
 
     @property
     def hole_parameters(self):
@@ -407,7 +412,7 @@ class EDBPadstack(object):
         list
             List of the hole parameters.
         """
-        self._hole_parameters = self._hole_params[2]
+        self._hole_parameters = self.hole_params[2]
         return self._hole_parameters
 
     @pyaedt_function_handler()
@@ -464,7 +469,7 @@ class EDBPadstack(object):
         list
             List of float values for hole properties.
         """
-        self._hole_properties = [i.ToDouble() for i in self._hole_params[2]]
+        self._hole_properties = [i.ToDouble() for i in self.hole_params[2]]
         return self._hole_properties
 
     @hole_properties.setter
@@ -485,7 +490,7 @@ class EDBPadstack(object):
         int
             Type of the hole.
         """
-        self._hole_type = self._hole_params[1]
+        self._hole_type = self.hole_params[1]
         return self._hole_type
 
     @property
@@ -497,7 +502,7 @@ class EDBPadstack(object):
         str
             Hole offset value for the X axis.
         """
-        self._hole_offset_x = self._hole_params[3].ToString()
+        self._hole_offset_x = self.hole_params[3].ToString()
         return self._hole_offset_x
 
     @hole_offset_x.setter
@@ -515,7 +520,7 @@ class EDBPadstack(object):
         str
             Hole offset value for the Y axis.
         """
-        self._hole_offset_y = self._hole_params[4].ToString()
+        self._hole_offset_y = self.hole_params[4].ToString()
         return self._hole_offset_y
 
     @hole_offset_y.setter
@@ -533,7 +538,7 @@ class EDBPadstack(object):
         str
             Value for the hole rotation.
         """
-        self._hole_rotation = self._hole_params[5].ToString()
+        self._hole_rotation = self.hole_params[5].ToString()
         return self._hole_rotation
 
     @hole_rotation.setter
@@ -911,6 +916,8 @@ class EDBPadstackInstance(object):
         self._pedb = _pedb
         self._bounding_box = []
         self._object_instance = None
+        self._position = []
+        self._pdef = None
 
     @property
     def object_instance(self):
@@ -992,7 +999,7 @@ class EDBPadstackInstance(object):
         if comp_name in self._pedb.core_components.components:
             return self._pedb.core_components.components[comp_name]
         else:  # pragma: no cover
-            return
+            return ""
 
     @property
     def pin(self):
@@ -1008,7 +1015,8 @@ class EDBPadstackInstance(object):
         str
             Name of the padstack definition.
         """
-        return self._edb_padstackinstance.GetPadstackDef().GetName()
+        self._pdef = self._edb_padstackinstance.GetPadstackDef().GetName()
+        return self._pdef
 
     @property
     def backdrill_top(self):
@@ -1019,14 +1027,41 @@ class EDBPadstackInstance(object):
         tuple
             Tuple of the layer name and drill diameter.
         """
-        layer = self._pedb.edb.Cell.Layer("", 1)
+        layer = self._pedb.edb.Cell.Layer("", self._pedb.edb.Cell.LayerType.SignalLayer)
         val = self._pedb.edb_value(0)
-        (
-            _,
-            depth,
-            diameter,
-        ) = self._edb_padstackinstance.GetBackDrillParametersLayerValue(layer, val, False)
-        return depth.GetName(), diameter.ToString()
+        if is_ironpython:  # pragma: no cover
+            diameter = _clr.StrongBox[type(val)]()
+            drill_to_layer = _clr.StrongBox[self._pedb.edb.Cell.ILayerReadOnly]()
+            flag = self._edb_padstackinstance.GetBackDrillParametersLayerValue(drill_to_layer, diameter, False)
+        else:
+            (
+                flag,
+                drill_to_layer,
+                diameter,
+            ) = self._edb_padstackinstance.GetBackDrillParametersLayerValue(layer, val, False)
+        if flag:
+            return drill_to_layer.GetName(), diameter.ToString()
+        else:
+            return
+
+    def set_backdrill_top(self, drill_depth, drill_diameter):
+        """Set backdrill from top.
+
+        Parameters
+        ----------
+        drill_depth : str
+            Name of the drill to layer.
+        drill_diameter : float, str
+            Diameter of backdrill size.
+
+        Returns
+        -------
+        bool
+            True if success, False otherwise.
+        """
+        layer = self._pedb.stackup.layers[drill_depth]._edb_layer
+        val = self._pedb.edb_value(drill_diameter)
+        return self._edb_padstackinstance.SetBackDrillParameters(layer, val, False)
 
     @property
     def backdrill_bottom(self):
@@ -1037,14 +1072,41 @@ class EDBPadstackInstance(object):
         tuple
             Tuple of the layer name and drill diameter.
         """
-        layer = self._pedb.edb.Cell.Layer("", 1)
+        layer = self._pedb.edb.Cell.Layer("", self._pedb.edb.Cell.LayerType.SignalLayer)
         val = self._pedb.edb_value(0)
-        (
-            _,
-            depth,
-            diameter,
-        ) = self._edb_padstackinstance.GetBackDrillParametersLayerValue(layer, val, True)
-        return depth.GetName(), diameter.ToString()
+        if is_ironpython:  # pragma: no cover
+            diameter = _clr.StrongBox[type(val)]()
+            drill_to_layer = _clr.StrongBox[self._pedb.edb.Cell.ILayerReadOnly]()
+            flag = self._edb_padstackinstance.GetBackDrillParametersLayerValue(drill_to_layer, diameter, True)
+        else:
+            (
+                flag,
+                drill_to_layer,
+                diameter,
+            ) = self._edb_padstackinstance.GetBackDrillParametersLayerValue(layer, val, True)
+        if flag:
+            return drill_to_layer.GetName(), diameter.ToString()
+        else:
+            return
+
+    def set_backdrill_bottom(self, drill_depth, drill_diameter):
+        """Set backdrill from bottom.
+
+        Parameters
+        ----------
+        drill_depth : str
+            Name of the drill to layer.
+        drill_diameter : float, str
+            Diameter of backdrill size.
+
+        Returns
+        -------
+        bool
+            True if success, False otherwise.
+        """
+        layer = self._pedb.stackup.layers[drill_depth]._edb_layer
+        val = self._pedb.edb_value(drill_diameter)
+        return self._edb_padstackinstance.SetBackDrillParameters(layer, val, True)
 
     @property
     def start_layer(self):
@@ -1128,14 +1190,14 @@ class EDBPadstackInstance(object):
 
     @net_name.setter
     def net_name(self, val):
-        if val in self._pedb.core_nets.nets:
-            net = self._pedb.core_nets.nets[val].net_object
-            self._edb_padstackinstance.SetNet(net)
-        elif not isinstance(val, str):
+        if not isinstance(val, str):
             try:
                 self._edb_padstackinstance.SetNet(val)
             except:
                 raise AttributeError("Value inserted not found. Input has to be net name or net object.")
+        elif val in self._pedb.core_nets.nets:
+            net = self._pedb.core_nets.nets[val].net_object
+            self._edb_padstackinstance.SetNet(net)
         else:
             raise AttributeError("Value inserted not found. Input has to be net name or net object.")
 
@@ -1170,10 +1232,14 @@ class EDBPadstackInstance(object):
         list
             List of ``[x, y]``` coordinates for the padstack instance position.
         """
+        self._position = []
         out = self._edb_padstackinstance.GetPositionAndRotationValue()
-        if out[0]:
-            return [out[1].X.ToDouble(), out[1].Y.ToDouble()]
-        return []
+        if self._edb_padstackinstance.GetComponent():
+            out2 = self._edb_padstackinstance.GetComponent().GetTransform().TransformPoint(out[1])
+            self._position = [out2.X.ToDouble(), out2.Y.ToDouble()]
+        elif out[0]:
+            self._position = [out[1].X.ToDouble(), out[1].Y.ToDouble()]
+        return self._position
 
     @position.setter
     def position(self, value):
@@ -1268,13 +1334,13 @@ class EDBPadstackInstance(object):
         Parameters
         ----------
         prefix : str, optional
-            Prefix for the variable name.
+            Prefix for the variable name. Default is ``None``.
             Example `"MyVariableName"` will create 2 Project variables $MyVariableNamesX and $MyVariableNamesY.
 
         Returns
         -------
         List
-            Variables created
+            List of variables created.
         """
         p = self.position
         if not prefix:
@@ -1310,13 +1376,14 @@ class EDBPadstackInstance(object):
         Parameters
         ----------
         net_name : str
-            Net name of the voids to be checked.
+            Net name of the voids to be checked. Default is ``None``.
         layer_name : str
-            Layer name of the voids to be checked.
+            Layer name of the voids to be checked. Default is ``None``.
+
         Returns
         -------
         list
-            List of the voids includes this padstack instance.
+            List of the voids that include this padstack instance.
         """
         x_pos = self._pedb.edb_value(self.position[0])
         y_pos = self._pedb.edb_value(self.position[1])
