@@ -16,7 +16,7 @@ from pyaedt.generic.general_methods import pyaedt_function_handler
 
 
 class SimulationConfigurationBatch(object):
-    """Class containing all Cuotut and Batch analysis settings.
+    """Contains all Cuotut and Batch analysis settings.
     The class is part of `SimulationConfiguration` class as a property.
 
     """
@@ -26,7 +26,7 @@ class SimulationConfigurationBatch(object):
         self._power_nets = []
         self._components = []
         self._cutout_subdesign_type = CutoutSubdesignType.Conformal  # Conformal
-        self._cutout_subdesign_expansion = 0.1
+        self._cutout_subdesign_expansion = 0.001
         self._cutout_subdesign_round_corner = True
         self._use_default_cutout = True
         self._generate_solder_balls = True
@@ -46,6 +46,7 @@ class SimulationConfigurationBatch(object):
         self._truncate_airbox_at_ground = False
         self._use_radiation_boundary = True
         self._do_cutout_subdesign = True
+        self._do_pin_group = True
         self._sources = []
 
     @property
@@ -174,6 +175,21 @@ class SimulationConfigurationBatch(object):
     def use_default_cutout(self, value):  # pragma: no cover
         self._use_default_cutout = value
 
+    @property
+    def do_pingroup(self):  # pragma: no cover
+        """Do pingroup on multi-pin component. ``True`` all pins from the same net are grouped, ``False`` one port
+        is created for each pin.
+
+        Returns
+        -------
+        bool
+        """
+        return self._do_pin_group
+
+    @do_pingroup.setter
+    def do_pingroup(self, value):  # pragma: no cover
+        self._do_pin_group = value
+
     @property
     def generate_solder_balls(self):  # pragma: no cover
         """Retrieve the boolean for applying solder balls.
@@ -470,7 +486,7 @@ class SimulationConfigurationBatch(object):
 
 
 class SimulationConfigurationDc(object):
-    """Class containing all DC analysis settings.
+    """Contains all DC analysis settings.
     The class is part of `SimulationConfiguration` class as a property.
 
     """
@@ -1020,7 +1036,7 @@ class SimulationConfigurationDc(object):
 
 
 class SimulationConfigurationAc(object):
-    """Class containing all AC analysis settings.
+    """Contains all AC analysis settings.
     The class is part of `SimulationConfiguration` class as a property.
 
     """
@@ -1781,6 +1797,7 @@ class SimulationConfiguration(object):
             self.import_json(filename)
         self._read_cfg()
         self._pedb = edb
+        self.SOLVER_TYPE = SolverType
 
     @property
     def open_edb_after_build(self):
@@ -2139,7 +2156,7 @@ class SimulationConfiguration(object):
             raise
 
     def _dict_to_json(self, dict_out, dict_in=None):
-        exclude = ["_pedb"]
+        exclude = ["_pedb", "SOLVER_TYPE"]
         for k, v in dict_in.items():
             if k in exclude:
                 continue
