@@ -6,12 +6,13 @@ import time
 
 from pyaedt.edb_core.edb_data.nets_data import EDBNetsData
 from pyaedt.edb_core.edb_data.padstacks_data import EDBPadstackInstance
+from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.generic.constants import CSS4_COLORS
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.generic.plot import plot_matplotlib
-from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.modeler.geometry_operators import GeometryOperators
 
 
 class EdbNets(object):
@@ -347,7 +348,10 @@ class EdbNets(object):
             layer_name = path.layer_name
             if net_name not in nets or layer_name not in layers:
                 continue
-            x, y = path.points()
+            try:
+                x, y = path.points()
+            except ValueError:
+                x = None
             if not x:
                 continue
             create_label = False
@@ -821,7 +825,7 @@ class EdbNets(object):
         Returns
         -------
         object
-            Net Object
+            Net Object.
         """
         if not net_name and not start_with and not contain and not end_with:
             net_name = generate_unique_name("NET_")
@@ -922,8 +926,8 @@ class EdbNets(object):
 
         >>> renamed_nets = edb_core.core_nets.find_and_fix_disjoint_nets(["GND","Net2"])
         """
+        timer_start = self._logger.reset_timer()
 
-        self._logger.reset_timer()
         if not net_list:
             net_list = list(self.nets.keys())
         elif isinstance(net_list, str):
@@ -944,7 +948,7 @@ class EdbNets(object):
                 _padstacks_list[n_name] = [pad]
         new_nets = []
         disjoints_objects = []
-
+        self._logger.reset_timer()
         for net in net_list:
             net_groups = []
             obj_dict = {}
@@ -965,20 +969,81 @@ class EdbNets(object):
                 for disjoints in sorted_list[1:]:
                     if keep_only_main_net:
                         for geo in disjoints:
-                            obj_dict[geo].delete()
+                            try:
+                                obj_dict[geo].delete()
+                            except KeyError:
+                                pass
                     elif len(disjoints) == 1 and (
                         isinstance(obj_dict[disjoints[0]], EDBPadstackInstance)
                         or clean_disjoints_less_than
                         and obj_dict[disjoints[0]].area() < clean_disjoints_less_than
                     ):
-                        obj_dict[disjoints[0]].delete()
+                        try:
+                            obj_dict[disjoints[0]].delete()
+                        except KeyError:
+                            pass
                     else:
-                        new_net_name = generate_unique_name(net, n=3)
-                        if self.find_or_create_net(new_net_name):
-                            new_nets.append(new_net_name)
+                        new_net_name = generate_unique_name(net, n=6)
+                        net_obj = self.find_or_create_net(new_net_name)
+                        if net_obj:
+                            new_nets.append(net_obj.GetName())
                             for geo in disjoints:
-                                obj_dict[geo].net_name = new_net_name
+                                try:
+                                    obj_dict[geo].net_name = net_obj
+                                except KeyError:
+                                    pass
                             disjoints_objects.extend(disjoints)
-        self._logger.info_timer("Disjoint Cleanup Completed.")
         self._logger.info("Found {} objects in {} new nets.".format(len(disjoints_objects), len(new_nets)))
+        self._logger.info_timer("Disjoint Cleanup Completed.", timer_start)
+
         return new_nets
+
+    @pyaedt_function_handler()
+    def merge_nets_polygons(self, net_list):
+        """Convert paths from net into polygons, evaluate all connected polygons and perform the merge.
+
+        Parameters
+        ----------
+        net_list : str or list[str]
+            net name of list of net name.
+
+        Returns
+            list of merged polygons.
+
+        -------
+
+        """
+        if isinstance(net_list, str):
+            net_list = [net_list]
+        returned_poly = []
+        for net in net_list:
+            if net in self.nets:
+                net_rtree = self._edb.Geometry.RTree()
+                paths = [prim for prim in self.nets[net].primitives if prim.type == "Path"]
+                for path in paths:
+                    path.convert_to_polygon()
+                polygons = [prim for prim in self.nets[net].primitives if prim.type == "Polygon"]
+                for polygon in polygons:
+                    polygon_data = polygon.primitive_object.GetPolygonData()
+                    rtree = self._edb.Geometry.RTreeObj(polygon_data, polygon.primitive_object)
+                    net_rtree.Insert(rtree)
+                connected_polygons = net_rtree.GetConnectedGeometrySets()
+                void_list = []
+                for pp in list(connected_polygons):
+                    for _pp in list(pp):
+                        _voids = list(_pp.Obj.Voids)
+                        void_list.extend(_pp.Obj.Voids)
+                for poly_list in list(connected_polygons):
+                    layer = list(poly_list)[0].Obj.GetLayer().GetName()
+                    net = list(poly_list)[0].Obj.GetNet()
+                    _poly_list = convert_py_list_to_net_list([obj.Poly for obj in list(poly_list)])
+                    merged_polygon = list(self._edb.Geometry.PolygonData.Unite(_poly_list))
+                    for poly in merged_polygon:
+                        for void in void_list:
+                            poly.AddHole(void.GetPolygonData())
+                        _new_poly = self._edb.Cell.Primitive.Polygon.Create(self._active_layout, layer, net, poly)
+                        returned_poly.append(_new_poly)
+                for init_poly in list(list(connected_polygons)):
+                    for _pp in list(init_poly):
+                        _pp.Obj.Delete()
+        return returned_poly
