@@ -21,7 +21,7 @@ from pyaedt.generic.constants import SweepType
 from pyaedt.generic.general_methods import _retry_ntimes
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.modeler.geometry_operators import GeometryOperators
 
 
 class EdbSiwave(object):
@@ -143,7 +143,7 @@ class EdbSiwave(object):
         if source.source_type in [SourceType.CoaxPort, SourceType.CircPort, SourceType.LumpedPort]:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
-            pos_pingroup_terminal.SetSourceAmplitude(self._get_edb_value(source.impedance))
+            pos_pingroup_terminal.SetImpedance(self._get_edb_value(source.impedance))
             if source.source_type == SourceType.CircPort:
                 pos_pingroup_terminal.SetIsCircuitPort(True)
                 neg_pingroup_terminal.SetIsCircuitPort(True)
@@ -266,7 +266,7 @@ class EdbSiwave(object):
         Returns
         -------
         str
-            Source Name
+            Source Name.
 
         Examples
         --------
@@ -898,6 +898,13 @@ class EdbSiwave(object):
             simsetup_info.Name = simulation_setup.setup_name
             simsetup_info.SimulationSettings.AdvancedSettings.PerformERC = False
             simsetup_info.SimulationSettings.UseCustomSettings = True
+            if simulation_setup.mesh_freq:  # pragma: no cover
+                if isinstance(simulation_setup.mesh_freq, str):
+                    simsetup_info.SimulationSettings.UseCustomSettings = True
+                    simsetup_info.SimulationSettings.AdvancedSettings.MeshAutoMatic = False
+                    simsetup_info.SimulationSettings.AdvancedSettings.MeshFrequency = simulation_setup.mesh_freq
+                else:
+                    self._logger.warning("Meshing frequency value must be a string with units")
             if simulation_setup.include_inter_plane_coupling:  # pragma: no cover
                 simsetup_info.SimulationSettings.AdvancedSettings.IncludeInterPlaneCoupling = (
                     simulation_setup.include_inter_plane_coupling
@@ -1067,7 +1074,7 @@ class EdbSiwave(object):
 
         Returns
         -------
-        Component
+        class:`pyaedt.edb_core.components.Components`
             Created EDB component.
 
         """
@@ -1092,6 +1099,7 @@ class EdbSiwave(object):
             List of pin names.
         group_name : str, optional
             Name of the pin group.
+
         Returns
         -------
         PinGroup
@@ -1125,6 +1133,7 @@ class EdbSiwave(object):
             Name of the net.
         group_name : str, optional
             Name of the pin group. The default value is ``None``.
+
         Returns
         -------
         PinGroup
@@ -1149,8 +1158,10 @@ class EdbSiwave(object):
             Magnitude of the source.
         phase : int, float, optional
             Phase of the source
+
         Returns
         -------
+        bool
 
         """
         pos_pin_group = self.pin_groups[pos_pin_group_name]
@@ -1182,8 +1193,10 @@ class EdbSiwave(object):
             Magnitude of the source.
         phase : int, float, optional
             Phase of the source
+
         Returns
         -------
+        bool
 
         """
         pos_pin_group = self.pin_groups[pos_pin_group_name]
@@ -1198,3 +1211,34 @@ class EdbSiwave(object):
         neg_terminal.SetName(name + "_ref")
         pos_terminal.SetReferenceTerminal(neg_terminal)
         return True
+
+    @pyaedt_function_handler
+    def create_circuit_port_on_pin_group(self, pos_pin_group_name, neg_pin_group_name, impedance=50, name=None):
+        """Create a port between two pin groups.
+
+        Parameters
+        ----------
+        pos_pin_group_name : str
+            Name of the positive pin group.
+        neg_pin_group_name : str
+            Name of the negative pin group.
+        impedance : int, float, optional
+            Impedance of the source.
+
+        Returns
+        -------
+        bool
+
+        """
+        pos_pin_group = self.pin_groups[pos_pin_group_name]
+        pos_terminal = pos_pin_group.create_port_terminal(impedance)
+        if name:  # pragma: no cover
+            pos_terminal.SetName(name)
+        else:
+            name = generate_unique_name("port")
+            pos_terminal.SetName(name)
+        neg_pin_group_name = self.pin_groups[neg_pin_group_name]
+        neg_terminal = neg_pin_group_name.create_port_terminal(impedance)
+        neg_terminal.SetName(name + "_ref")
+        pos_terminal.SetReferenceTerminal(neg_terminal)
+        return True
