@@ -8,539 +8,33 @@ from __future__ import absolute_import  # noreorder
 import json
 import logging
 import math
+import os.path
 import warnings
 from collections import OrderedDict
 
 from pyaedt.edb_core.edb_data.layer_data import EDBLayers
+from pyaedt.edb_core.edb_data.layer_data import LayerEdbClass
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 
 pd = None
+np = None
 if not is_ironpython:
     try:
         import numpy as np
+    except ImportError:
+        np = None
+
+    try:
         import pandas as pd
     except ImportError:
-        warnings.warn(
-            "The Pandas module is required to run some functionalities.\n" "Install with \n\npip install pandas\n"
-        )
+        pd = None
 
 
 logger = logging.getLogger(__name__)
 
 
-class LayerEdbClass(object):
-    """New Edb Layer management class. Replaces EDBLayer."""
-
-    def __init__(self, pclass, name):
-        self._pclass = pclass
-        self._name = name
-        self._color = ()
-        self._type = ""
-        self._material = ""
-        self._conductivity = 0.0
-        self._permittivity = 0.0
-        self._loss_tangent = 0.0
-        self._dielectric_fill = ""
-        self._thickness = 0.0
-        self._etch_factor = 0.0
-        self._roughness_enabled = False
-        self._top_hallhuray_nodule_radius = 0.5e-6
-        self._top_hallhuray_surface_ratio = 2.9
-        self._bottom_hallhuray_nodule_radius = 0.5e-6
-        self._bottom_hallhuray_surface_ratio = 2.9
-        self._side_hallhuray_nodule_radius = 0.5e-6
-        self._side_hallhuray_surface_ratio = 2.9
-        self._material = None
-        self._upper_elevation = 0.0
-        self._lower_elevation = 0.0
-
-    @property
-    def lower_elevation(self):
-        """Lower elevation.
-
-        Returns
-        -------
-        float
-            Lower elevation.
-        """
-        try:
-            self._lower_elevation = self._edb_layer.GetLowerElevation()
-        except:
-            pass
-        return self._lower_elevation
-
-    @property
-    def upper_elevation(self):
-        """Upper elevation.
-
-        Returns
-        -------
-        float
-            Upper elevation.
-        """
-        try:
-            self._upper_elevation = self._edb_layer.GetUpperElevation()
-        except:
-            pass
-        return self._upper_elevation
-
-    @property
-    def _edb(self):
-        return self._pclass._pedb.edb
-
-    @property
-    def _edb_layer(self):
-        for l in self._pclass._edb_layer_list:
-            if l.GetName() == self._name:
-                return l.Clone()
-
-    @property
-    def is_stackup_layer(self):
-        """Determine whether this layer is a stackup layer.
-
-        Returns
-        -------
-        bool
-            True if this layer is a stackup layer, False otherwise.
-        """
-        return self._edb_layer.IsStackupLayer()
-
-    @property
-    def color(self):
-        """Retrieve color of the layer.
-
-        Returns
-        -------
-        tuple
-            RGB.
-        """
-        layer_color = self._edb_layer.GetColor()
-        return layer_color.Item1, layer_color.Item2, layer_color.Item3
-
-    @color.setter
-    def color(self, rgb):
-        layer_clone = self._edb_layer
-        layer_clone.SetColor(*rgb)
-        self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-        self._color = rgb
-
-    @property
-    def name(self):
-        """Retrieve name of the layer.
-
-        Returns
-        -------
-        str
-        """
-        return self._edb_layer.GetName()
-
-    @name.setter
-    def name(self, name):
-        layer_clone = self._edb_layer
-        layer_clone.SetName(name)
-        self._pclass._set_layout_stackup(layer_clone, "change_name", self._name)
-        self._name = name
-
-    @property
-    def type(self):
-        """Retrieve type of the layer."""
-        if self._edb_layer.GetLayerType() == self._edb.Cell.LayerType.SignalLayer:
-            return "signal"
-        elif self._edb_layer.GetLayerType() == self._edb.Cell.LayerType.DielectricLayer:
-            return "dielectric"
-        else:
-            return
-
-    @type.setter
-    def type(self, new_type):
-        if new_type == self.type:
-            return
-        if new_type == "signal":
-            self._edb_layer.SetLayerType(self._edb.Cell.LayerType.SignalLayer)
-            self._type = new_type
-        elif new_type == "dielectric":
-            self._edb_layer.SetLayerType(self._edb.Cell.LayerType.DielectricLayer)
-            self._type = new_type
-        else:
-            return
-
-    @property
-    def material(self):
-        """Get/Set the material loss_tangent.
-
-        Returns
-        -------
-        float
-        """
-        return self._edb_layer.GetMaterial()
-
-    @material.setter
-    def material(self, name):
-        layer_clone = self._edb_layer
-        layer_clone.SetMaterial(name)
-        self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-        self._material = name
-
-    @property
-    def conductivity(self):
-        """Get the material conductivity.
-
-        Returns
-        -------
-        float
-        """
-        if self.material in self._pclass._pedb.materials.materials:
-            self._conductivity = self._pclass._pedb.materials[self.material].conductivity
-            return self._conductivity
-
-        return None
-
-    @property
-    def permittivity(self):
-        """Get the material permittivity.
-
-        Returns
-        -------
-        float
-        """
-        if self.material in self._pclass._pedb.materials.materials:
-            self._permittivity = self._pclass._pedb.materials[self.material].permittivity
-            return self._permittivity
-        return None
-
-    @property
-    def loss_tangent(self):
-        """Get the material loss_tangent.
-
-        Returns
-        -------
-        float
-        """
-        if self.material in self._pclass._pedb.materials.materials:
-            self._loss_tangent = self._pclass._pedb.materials[self.material].loss_tangent
-            return self._loss_tangent
-        return None
-
-    @property
-    def dielectric_fill(self):
-        """Retrieve material name of the layer dielectric fill."""
-        if self.type == "signal":
-            self._dielectric_fill = self._edb_layer.GetFillMaterial()
-            return self._dielectric_fill
-        else:
-            return
-
-    @dielectric_fill.setter
-    def dielectric_fill(self, name):
-        if self.type == "signal":
-            layer_clone = self._edb_layer
-            layer_clone.SetFillMaterial(name)
-            self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-            self._dielectric_fill = name
-        else:
-            pass
-
-    @property
-    def thickness(self):
-        """Retrieve thickness of the layer.
-
-        Returns
-        -------
-        float
-        """
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        self._thickness = self._edb_layer.GetThicknessValue().ToDouble()
-        return self._thickness
-
-    @thickness.setter
-    def thickness(self, value):
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        layer_clone = self._edb_layer
-        layer_clone.SetThickness(self._pclass._edb_value(value))
-        self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-        self._thickness = value
-
-    @property
-    def etch_factor(self):
-        """Retrieve etch factor of this layer.
-
-        Returns
-        -------
-        float
-        """
-        self._etch_factor = self._edb_layer.GetEtchFactor().ToDouble()
-        return self._etch_factor
-
-    @etch_factor.setter
-    def etch_factor(self, value):
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        if not value:
-            layer_clone = self._edb_layer
-            layer_clone.SetEtchFactorEnabled(False)
-        else:
-            layer_clone = self._edb_layer
-            layer_clone.SetEtchFactorEnabled(True)
-            layer_clone.SetEtchFactor(self._pclass._edb_value(value))
-        self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-        self._etch_factor = value
-
-    @property
-    def roughness_enabled(self):
-        """Determine whether roughness is enabled on this layer.
-
-        Returns
-        -------
-        bool
-        """
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        self._roughness_enabled = self._edb_layer.IsRoughnessEnabled()
-        return self._roughness_enabled
-
-    @roughness_enabled.setter
-    def roughness_enabled(self, set_enable):
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        self._roughness_enabled = set_enable
-        if set_enable:
-            layer_clone = self._edb_layer
-            layer_clone.SetRoughnessEnabled(True)
-            self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-            self.assign_roughness_model()
-        else:
-            layer_clone = self._edb_layer
-            layer_clone.SetRoughnessEnabled(False)
-            self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-
-    @property
-    def top_hallhuray_nodule_radius(self):
-        top_roughness_model = self.get_roughness_model("top")
-        if top_roughness_model:
-            self._top_hallhuray_nodule_radius = top_roughness_model.NoduleRadius.ToDouble()
-        return self._top_hallhuray_nodule_radius
-
-    @top_hallhuray_nodule_radius.setter
-    def top_hallhuray_nodule_radius(self, value):
-        self._top_hallhuray_nodule_radius = value
-
-    @property
-    def top_hallhuray_surface_ratio(self):
-        top_roughness_model = self.get_roughness_model("top")
-        if top_roughness_model:
-            self._top_hallhuray_surface_ratio = top_roughness_model.SurfaceRatio.ToDouble()
-        return self._top_hallhuray_surface_ratio
-
-    @top_hallhuray_surface_ratio.setter
-    def top_hallhuray_surface_ratio(self, value):
-        self._top_hallhuray_surface_ratio = value
-
-    @property
-    def bottom_hallhuray_nodule_radius(self):
-        bottom_roughness_model = self.get_roughness_model("bottom")
-        if bottom_roughness_model:
-            self._bottom_hallhuray_nodule_radius = bottom_roughness_model.NoduleRadius.ToDouble()
-        return self._bottom_hallhuray_nodule_radius
-
-    @bottom_hallhuray_nodule_radius.setter
-    def bottom_hallhuray_nodule_radius(self, value):
-        self._bottom_hallhuray_nodule_radius = value
-
-    @property
-    def bottom_hallhuray_surface_ratio(self):
-        bottom_roughness_model = self.get_roughness_model("bottom")
-        if bottom_roughness_model:
-            self._bottom_hallhuray_surface_ratio = bottom_roughness_model.SurfaceRatio.ToDouble()
-        return self._bottom_hallhuray_surface_ratio
-
-    @bottom_hallhuray_surface_ratio.setter
-    def bottom_hallhuray_surface_ratio(self, value):
-        self._bottom_hallhuray_surface_ratio = value
-
-    @property
-    def side_hallhuray_nodule_radius(self):
-        side_roughness_model = self.get_roughness_model("side")
-        if side_roughness_model:
-            self._side_hallhuray_nodule_radius = side_roughness_model.NoduleRadius.ToDouble()
-        return self._side_hallhuray_nodule_radius
-
-    @side_hallhuray_nodule_radius.setter
-    def side_hallhuray_nodule_radius(self, value):
-        self._side_hallhuray_nodule_radius = value
-
-    @property
-    def side_hallhuray_surface_ratio(self):
-        side_roughness_model = self.get_roughness_model("side")
-        if side_roughness_model:
-            self._side_hallhuray_surface_ratio = side_roughness_model.SurfaceRatio.ToDouble()
-        return self._side_hallhuray_surface_ratio
-
-    @side_hallhuray_surface_ratio.setter
-    def side_hallhuray_surface_ratio(self, value):
-        self._side_hallhuray_surface_ratio = value
-
-    @pyaedt_function_handler()
-    def get_roughness_model(self, surface="top"):
-        """Gets roughness model of the layer.
-
-        Parameters
-        ----------
-        surface : str, optional
-            Where to fetch roughness model. The default is ``"top"``. Options are ``"top"``, ``"bottom"``, ``"side"``.
-
-        Returns
-        -------
-        ``"Ansys.Ansoft.Edb.Cell.RoughnessModel"``
-
-        """
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        if surface == "top":
-            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top)
-        elif surface == "bottom":
-            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom)
-        elif surface == "side":
-            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side)
-
-    @pyaedt_function_handler()
-    def assign_roughness_model(
-        self,
-        model_type="huray",
-        huray_radius="0.5um",
-        huray_surface_ratio="2.9",
-        groisse_roughness="1um",
-        apply_on_surface="all",
-    ):
-        """Assign roughness model on this layer.
-
-        Parameters
-        ----------
-        model_type : str, optional
-            Type of roughness model. The default is ``"huray"``. Options are ``"huray"``, ``"groisse"``.
-        huray_radius : str, float, optional
-            Radius of huray model. The default is ``"0.5um"``.
-        huray_surface_ratio : str, float, optional.
-            Surface ratio of huray model. The default is ``"2.9"``.
-        groisse_roughness : str, float, optional
-            Roughness of groisse model. The default is ``"1um"``.
-        apply_on_surface : str, optional.
-            Where to assign roughness model. The default is ``"all"``. Options are ``"top"``, ``"bottom"``,
-             ``"side"``.
-        Returns
-        -------
-
-        """
-        if not self.is_stackup_layer:  # pragma: no cover
-            return
-        radius = self._pclass._edb_value(huray_radius)
-        self._hurray_nodule_radius = huray_radius
-        surface_ratio = self._pclass._edb_value(huray_surface_ratio)
-        self._hurray_surface_ratio = huray_surface_ratio
-        groisse_roughness = self._pclass._edb_value(groisse_roughness)
-        regions = []
-        if apply_on_surface == "all":
-            self._side_roughness = "all"
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top,
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side,
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom,
-            ]
-        elif apply_on_surface == "top":
-            self._side_roughness = "top"
-            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top]
-        elif apply_on_surface == "bottom":
-            self._side_roughness = "bottom"
-            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom]
-        elif apply_on_surface == "side":
-            self._side_roughness = "side"
-            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side]
-
-        layer_clone = self._edb_layer
-        for r in regions:
-            if model_type == "huray":
-                model = self._pclass._pedb.edb.Cell.HurrayRoughnessModel(radius, surface_ratio)
-            else:
-                model = self._pclass._pedb.edb.Cell.GroisseRoughnessModel(groisse_roughness)
-            layer_clone.SetRoughnessModel(r, model)
-        return self._pclass._set_layout_stackup(layer_clone, "change_attribute")
-
-    @pyaedt_function_handler()
-    def _json_format(self):
-        dict_out = {}
-        self._color = self.color
-        self._dielectric_fill = self.dielectric_fill
-        self._etch_factor = self.etch_factor
-        self._material = self.material
-        self._name = self.name
-        self._roughness_enabled = self.roughness_enabled
-        self._thickness = self.thickness
-        self._type = self.type
-        self._roughness_enabled = self.roughness_enabled
-        self._top_hallhuray_nodule_radius = self.top_hallhuray_nodule_radius
-        self._top_hallhuray_surface_ratio = self.top_hallhuray_surface_ratio
-        self._side_hallhuray_nodule_radius = self.side_hallhuray_nodule_radius
-        self._side_hallhuray_surface_ratio = self.side_hallhuray_surface_ratio
-        self._bottom_hallhuray_nodule_radius = self.bottom_hallhuray_nodule_radius
-        self._bottom_hallhuray_surface_ratio = self.bottom_hallhuray_surface_ratio
-        for k, v in self.__dict__.items():
-            if (
-                not k == "_pclass"
-                and not k == "_conductivity"
-                and not k == "_permittivity"
-                and not k == "_loss_tangent"
-            ):
-                dict_out[k[1:]] = v
-        return dict_out
-
-    def _load_layer(self, layer):
-        if layer:
-            self.color = layer["color"]
-            self.type = layer["type"]
-            if isinstance(layer["material"], str):
-                self.material = layer["material"]
-            else:
-                self._pclass._pedb.materials._load_materials(layer["material"])
-                self.material = layer["material"]["name"]
-            if layer["dielectric_fill"]:
-                if isinstance(layer["dielectric_fill"], str):
-                    self.dielectric_fill = layer["dielectric_fill"]
-                else:
-                    self._pclass._pedb.materials._load_materials(layer["dielectric_fill"])
-                    self.dielectric_fill = layer["dielectric_fill"]["name"]
-            self.thickness = layer["thickness"]
-            self.etch_factor = layer["etch_factor"]
-            self.roughness_enabled = layer["roughness_enabled"]
-            if self.roughness_enabled:
-                self.top_hallhuray_nodule_radius = layer["top_hallhuray_nodule_radius"]
-                self.top_hallhuray_surface_ratio = layer["top_hallhuray_surface_ratio"]
-                self.assign_roughness_model(
-                    "huray",
-                    layer["top_hallhuray_nodule_radius"],
-                    layer["top_hallhuray_surface_ratio"],
-                    apply_on_surface="top",
-                )
-                self.bottom_hallhuray_nodule_radius = layer["bottom_hallhuray_nodule_radius"]
-                self.bottom_hallhuray_surface_ratio = layer["bottom_hallhuray_surface_ratio"]
-                self.assign_roughness_model(
-                    "huray",
-                    layer["bottom_hallhuray_nodule_radius"],
-                    layer["bottom_hallhuray_surface_ratio"],
-                    apply_on_surface="bottom",
-                )
-                self.side_hallhuray_nodule_radius = layer["side_hallhuray_nodule_radius"]
-                self.side_hallhuray_surface_ratio = layer["side_hallhuray_surface_ratio"]
-                self.assign_roughness_model(
-                    "huray",
-                    layer["side_hallhuray_nodule_radius"],
-                    layer["side_hallhuray_surface_ratio"],
-                    apply_on_surface="side",
-                )
-
-
 class Stackup(object):
     """Manages EDB methods for stackup accessible from `Edb.stackup` property."""
 
@@ -550,6 +44,10 @@ class Stackup(object):
     def __init__(self, pedb):
         self._pedb = pedb
 
+    @property
+    def _logger(self):
+        return self._pedb.logger
+
     @property
     def layer_types(self):
         """Layer types.
@@ -633,6 +131,9 @@ class Stackup(object):
         -------
         bool
         """
+        if not np:
+            self._pedb.logger.error("Numpy is needed. Please, install it first.")
+            return False
         if not layer_count % 2 == 0:
             return False
 
@@ -806,7 +307,7 @@ class Stackup(object):
         return self._pedb.edb_value(value)
 
     @pyaedt_function_handler()
-    def _set_layout_stackup(self, layer_clone, operation, base_layer=None):
+    def _set_layout_stackup(self, layer_clone, operation, base_layer=None, method=1):
         """Internal method. Apply stackup change into EDB.
 
         Parameters
@@ -829,7 +330,7 @@ class Stackup(object):
             new_layer_collection = self._pedb.edb.Cell.LayerCollection()
             for layer in edb_layers:
                 to_layer = layer.Clone()
-                if to_layer.IsStackupLayer():
+                if to_layer.IsStackupLayer() or (to_layer.GetName().lower() == "outline" and method == 1):
                     new_layer_collection.AddLayerBottom(to_layer)
                 else:
                     non_stackup.append(to_layer)
@@ -961,7 +462,18 @@ class Stackup(object):
         -------
 
         """
+        if layer_name in self.layers:
+            logger.error("layer {} exists.".format(layer_name))
+            return False
         materials_lower = {m.lower(): m for m in list(self._pedb.materials.materials.keys())}
+        if not material:
+            if layer_type == "signal":
+                material = "copper"
+            else:
+                material = "fr4_epoxy"
+        if not fillMaterial:
+            fillMaterial = "fr4_epoxy"
+
         if material.lower() not in materials_lower:
             logger.error(material + " does not exist in material library")
         else:
@@ -979,8 +491,10 @@ class Stackup(object):
             if layer_type != "dielectric":
                 new_layer.SetFillMaterial(fillMaterial)
             new_layer.SetNegative(is_negative)
+            l1 = len(self.layers)
             self._set_layout_stackup(new_layer, method, base_layer)
-
+            if len(self.layers) == l1:
+                self._set_layout_stackup(new_layer, method, base_layer, method=2)
             if etch_factor:
                 new_layer = self.layers[layer_name]
                 new_layer.etch_factor = etch_factor
@@ -1018,8 +532,13 @@ class Stackup(object):
         Parameters
         ----------
         fpath : str
-            File path to csv file.
+            File path to csv or json file.
         """
+        if not pd:
+            self._pedb.logger.error("Pandas is needed. Please, install it first.")
+            return False
+        if os.path.splitext(fpath)[1] == ".json":
+            return self._import_layer_stackup(fpath)
         if is_ironpython:
             self._pedb.logger.error("Method working on CPython only.")
             return False
@@ -1066,16 +585,35 @@ class Stackup(object):
         return True
 
     @pyaedt_function_handler
-    def export_stackup(self, fpath, file_format="csv"):
-        """Export stackup definition to csv file.
+    def export_stackup(self, fpath, file_format="csv", include_material_with_layer=False):
+        """Export stackup definition to a CSV or JSON file.
 
         Parameters
         ----------
         fpath : str
-            File path to csv file.
+            File path to csv or json file.
         file_format : str, optional
-            The format of the file to be exported. The default is ``"csv"``. Options are ``"csv"``, ``"xlsx"``.
+            Format of the file to export. The default is ``"csv"``. Options are ``"csv"``, ``"xlsx"``,
+            ``"json"``.
+        include_material_with_layer : bool, optional.
+            Whether to include the material definition inside layer ones. This parameter is only used
+            when a JSON file is exported. The default is ``False``, which keeps the material definition
+            section in the JSON file. If ``True``, the material definition is included inside the layer ones.
+
         """
+        if file_format.lower() in ["csv", "xlsx"]:
+            return self._export_layer_stackup_to_csv_xlsx(fpath, file_format)
+        elif file_format.lower() == "json":
+            self._export_layer_stackup_to_json(fpath, include_material_with_layer)
+        else:
+            self._logger.warning("Layer stackup format is not supported. Skipping import.")
+            return False
+
+    @pyaedt_function_handler()
+    def _export_layer_stackup_to_csv_xlsx(self, fpath=None, file_format=None):
+        if not pd:
+            self._pedb.logger.error("Pandas is needed. Please, install it first.")
+            return False
         if is_ironpython:
             return
         data = {
@@ -1143,7 +681,37 @@ class Stackup(object):
                     for material in v.values():
                         self._pedb.materials._load_materials(material)
                 if k == "layers":
+                    if len(list(v.values())) == len(list(self.stackup_layers.values())):
+                        imported_layers_list = [l_dict["name"] for l_dict in list(v.values())]
+                        layout_layer_list = list(self.stackup_layers.keys())
+                        for layer_name in imported_layers_list:
+                            layer_index = imported_layers_list.index(layer_name)
+                            if layout_layer_list[layer_index] != layer_name:
+                                self.stackup_layers[layout_layer_list[layer_index]].name = layer_name
+                    prev_layer = None
                     for layer_name, layer in v.items():
+                        if layer["name"] not in self.stackup_layers:
+                            if not prev_layer:
+                                self.add_layer(
+                                    layer_name,
+                                    method="add_on_top",
+                                    layer_type=layer["type"],
+                                    material=layer["material"],
+                                    fillMaterial=layer["dielectric_fill"],
+                                    thickness=layer["thickness"],
+                                )
+                                prev_layer = layer_name
+                            else:
+                                self.add_layer(
+                                    layer_name,
+                                    base_layer=layer_name,
+                                    method="insert_below",
+                                    layer_type=layer["type"],
+                                    material=layer["material"],
+                                    fillMaterial=layer["dielectric_fill"],
+                                    thickness=layer["thickness"],
+                                )
+                                prev_layer = layer_name
                         if layer_name in self.stackup_layers:
                             self.stackup_layers[layer["name"]]._load_layer(layer)
             return True
@@ -1674,9 +1242,40 @@ class Stackup(object):
 
         return True
 
+    @pyaedt_function_handler
+    def residual_copper_area_per_layer(self):
+        """Report residual copper area per layer in percentage.
+
+        Returns
+        -------
+        dict
+            Copper area per layer.
+
+        Examples
+        --------
+        >>> edb = Edb(edbpath=targetfile1,  edbversion="2021.2")
+        >>> edb.stackup.residual_copper_area_per_layer()
+        """
+        temp_data = {name: 0 for name, _ in self.signal_layers.items()}
+        outline_area = 0
+        for i in self._pedb.core_primitives.primitives:
+            layer_name = i.GetLayer().GetName()
+            if layer_name.lower() == "outline":
+                if i.area() > outline_area:
+                    outline_area = i.area()
+            elif layer_name not in temp_data:
+                continue
+            elif not i.is_void:
+                temp_data[layer_name] = temp_data[layer_name] + i.area()
+            else:
+                pass
+        temp_data = {name: area / outline_area * 100 for name, area in temp_data.items()}
+        return temp_data
+
 
 class EdbStackup(object):
-    """Manages EDB methods for stackup and material management accessible from `Edb.core_stackup` property.
+    """Manages EDB methods for stackup and material management accessible from the
+     ``Edb.core_stackup`` property (deprecated).
 
     .. deprecated:: 0.6.5
         This class has been deprecated and replaced by the ``Stackup`` class.
@@ -1800,7 +1399,8 @@ class EdbStackup(object):
         """Create a conductor with simple properties.
 
         .. deprecated:: 0.6.27
-           Use :func:`Edb.materials.add_conductor_material` function instead.
+           Use the :func:`Edb.materials.add_conductor_material` function instead.
+
         Parameters
         ----------
         name : str
@@ -1810,7 +1410,7 @@ class EdbStackup(object):
 
         Returns
         -------
-        type
+        :class:`pyaedt.edb_core.materials.Material`
             Material definition.
         """
         warnings.warn("Use `Edb.materials.add_conductor_material` function instead.", DeprecationWarning)
@@ -1937,7 +1537,7 @@ class EdbStackup(object):
     @pyaedt_function_handler()
     def duplicate_material(self, material_name, new_material_name):
         """Duplicate a material from the database.
-        It duplicates these five properties: ``permittivity``, ``permeability``, ` conductivity,``
+        It duplicates these five properties: ``permittivity``, ``permeability``, ``conductivity``,
         ``dielectriclosstangent``, and ``magneticlosstangent``.
 
         .. deprecated:: 0.6.27
@@ -2010,7 +1610,7 @@ class EdbStackup(object):
         Returns
         -------
         float
-            the float value of the property.
+            The float value of the property.
 
 
         Examples
