@@ -2,209 +2,22 @@ from __future__ import absolute_import
 
 import os
 import sys
+import warnings
 from importlib import import_module
 
+import pyaedt.generic.constants as consts
 from pyaedt import generate_unique_project_name
 from pyaedt.application.AnalysisEmit import FieldAnalysisEmit
+from pyaedt.emit_core import EmitConstants
 from pyaedt.generic.general_methods import pyaedt_function_handler
 
 # global variable used to store module import
 mod = None
 
 
-class Interaction_Domain:
+class Results:
     """
-    Provides the ``Interaction_Domain`` object.
-
-    Examples
-    --------
-    Create an instance of the ``Interaction_Domain`` object.
-
-    >>> domain = Interaction_Domain()
-    >>> domain.set_receivers("Radio", "Tx-Band")
-    >>> interaction = self.aedtapp.results.revisions_list[-1].run(domain)
-    """
-
-    def __init__(self):
-        self.emit_api = mod.EmitApi()
-        self._obj = mod.InteractionDomain()
-        print(str(type(self._obj)))
-        try:
-            self._obj = mod.InteractionDomain()
-        except NameError:
-            raise ValueError("An Emit object must be initialized before an Interaction_Domain object is generated.")
-
-    def set_receiver(self, radioname, bandname="", frequency=-1):
-        """
-        Set the receiver, with optionality to specify the following:
-            > radio name
-            > radio name and a band name
-            > radio name, band name and a channel frequency
-
-        Examples
-        ----------
-        >>> domain.set_receiver("Radio1", "Rx-Band", 2000)
-        """
-        self._obj.set_receiver(radioname, bandname, frequency)
-
-    @pyaedt_function_handler()
-    def set_interferers(self, radionames, bandnames=None, frequencies=None):
-        """
-        Set the interferers, with optionality to specify the following:
-            > radio name
-            > radio name and a band name
-            > radio name, band name and a channel frequency
-
-        Returns
-        -------
-
-        Examples
-        ----------
-        >>> radios = ["Radio1", "Radio2", "Bluetooth"]
-        >>> bands = ["Rx-Band", "Rx-Band", "Rx-Band"]
-        >>> frequencies = []
-        >>> domain.set_receiver(radios, bands, frequencies)
-        """
-        interfer_radio_names = []
-        interferer_band_names = []
-        interfer_frequencies = []
-        index = 0
-        for radio in radionames:
-            interfer_radio_names.append(radio)
-            if bandnames is not None:
-                if index >= len(bandnames):
-                    interferer_band_names.append("")
-                else:
-                    interferer_band_names.append(bandnames[index])
-            else:
-                interferer_band_names.append("")
-            if frequencies is not None:
-                if index >= len(frequencies):
-                    interfer_frequencies.append(-1)
-                else:
-                    interfer_frequencies.append(frequencies[index])
-            else:
-                interfer_frequencies.append(-1)
-            index = index + 1
-        self._obj.set_interferers(interfer_radio_names, interferer_band_names, interfer_frequencies)
-
-    @property
-    def receiver_name(self):
-        """
-        Get the receiver name from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        receiver_name : str
-            Receiver name associated with a domain.
-
-        Examples
-        ----------
-        >>> rx_name = domain.receiver_name
-        """
-        return self._obj.receiver_name
-
-    @property
-    def receiver_band_name(self):
-        """
-        Get the receiver band name from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        receiver_band_name : str
-            Receiver band name associated with a domain.
-
-        Examples
-        ----------
-        >>> rx_band_name = domain.receiver_band_name
-        """
-        return self._obj.receiver_band_name
-
-    @property
-    def receiver_channel_frequency(self):
-        """
-        Get the receiver channel frequency from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        receiver_channel_frequency : float
-            Receiver channel frequency associated with a domain.
-
-        Examples
-        ----------
-        >>> rx_freq = domain.receiver_channel_frequency
-        """
-        return self._obj.receiver_channel
-
-    @property
-    def interferer_names(self):
-        """
-        Get the interferer names from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        interferer_names : list(str)
-            Interferer names associated with a domain.
-
-        Examples
-        ----------
-        >>> tx_names = domain.interferer_names
-        """
-        return list(self._obj.interferer_names)
-
-    @property
-    def interferer_band_names(self):
-        """
-        Get the interferer band names from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        interferer_band_names : list(str)
-            Interferer band names associated with a domain.
-
-        Examples
-        ----------
-        >>> tx_band_names = domain.interferer_band_names
-        """
-        return list(self._obj.interferer_band_names)
-
-    @property
-    def interferer_channel_frequencies(self):
-        """
-        Get the interferer channel frequencies from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        interferer_channel_frequencies : list(float)
-            Interferer channel frequencies associated with a domain.
-
-        Examples
-        ----------
-        >>> tx_frequencies = domain.interferer_channel_frequencies
-        """
-
-        return list(self._obj.interferer_channel_frequencies)
-
-    @property
-    def instance_count(self):
-        """
-        Get the instance count from the ``Interaction_Domain`` object.
-
-        Returns
-        -------
-        instance_count: int
-            Instance count associated with a domain
-
-        Examples
-        ----------
-        >>> rx_name = domain.instance_count
-        """
-        return self._obj.instance_count()
-
-
-class Result:
-    """
-    Provides the ``Result`` object.
+    Provides the ``Results`` object.
 
     Parameters
     ----------
@@ -215,17 +28,29 @@ class Result:
     --------
     Create an instance of the ``Result`` object.
 
-    >>> aedtapp.results = Result()
+    >>> aedtapp.results = Results()
     >>> mode = Emit.tx_rx_mode().rx
     >>> radio_RX = aedtapp.results.get_radio_names(mode)
     """
 
     def __init__(self, emit_obj):
         self._result_loaded = False
+        """``True`` if the results are loaded and ``False`` if they are not."""
+
         self.emit_api = mod.EmitApi()
+        """Instance of the Emit api."""
+
         self.revisions_list = []
+        """List of all loaded result revisions."""
+
         self.location = emit_obj.oproject.GetPath()
+        """Path to the current project."""
+
         self.current_design = 0
+        """Initial revision of the Emit design."""
+
+        self.units = emit_obj.units
+        """Project units."""
 
     @property
     def result_loaded(self):
@@ -276,7 +101,7 @@ class Result:
             radios = self.emit_api.get_radio_names(tx_rx)
         else:
             radios = None
-            Result.result_mode_error()
+            Results.result_mode_error()
         return radios
 
     @pyaedt_function_handler()
@@ -304,11 +129,11 @@ class Result:
             bands = self.emit_api.get_band_names(radio_name, tx_rx_mode)
         else:
             bands = None
-            Result.result_mode_error()
+            Results.result_mode_error()
         return bands
 
     @pyaedt_function_handler()
-    def get_active_frequencies(self, radio_name, band_name, tx_rx_mode):
+    def get_active_frequencies(self, radio_name, band_name, tx_rx_mode, units=""):
 
         """
         Get a list of active frequencies for a ``tx`` or ``rx`` band in a radio.
@@ -321,11 +146,13 @@ class Result:
            Name of the band.
         tx_rx : tx_rx_mode object
             Used for determining whether to get ``rx`` or ``tx`` radio names.
+        units : str
+            Units for the frequencies.
 
         Returns
         -------
         freq:class:`list of float`
-            list of tx or or rx radio frequencies
+            List of tx or or rx radio frequencies.
 
         Examples
         ----------
@@ -333,9 +160,13 @@ class Result:
         """
         if self.result_loaded:
             freq = self.emit_api.get_active_frequencies(radio_name, band_name, tx_rx_mode)
+            # Emit api returns freqs in Hz, convert to user's desired units.
+            if not units or units not in EmitConstants.EMIT_VALID_UNITS["Frequency"]:
+                units = self.units["Frequency"]
+            freq = consts.unit_converter(freq, "Freq", "Hz", units)
         else:
             freq = None
-            Result.result_mode_error()
+            Results.result_mode_error()
         return freq
 
 
@@ -357,7 +188,7 @@ class Revision:
 
     >>> aedtapp = Emit()
     >>> rev = Revision(aedtapp, "Revision 1")
-    >>> domain = Interaction_Domain()
+    >>> domain = aedtapp.interaction_domain()
     >>> rev.run(domain)
     """
 
@@ -376,8 +207,13 @@ class Revision:
         else:
             full = subfolder + "/{}.emit".format(name)
         self.name = name
+        """Name of the revision."""
+
         self.path = full
+        """Full path of the revision."""
+
         self.emit_obj = emit_obj
+        """''Emit'' object associated with the revision."""
 
     @pyaedt_function_handler()
     def run(self, domain):
@@ -396,20 +232,20 @@ class Revision:
 
         Examples
         ----------
-        >>> domain = Interaction_Domain()
+        >>> domain = aedtapp.interaction_domain()
         >>> rev.run(domain)
 
         """
-        self.emit_obj._load_revision(self.path)
-        eng = self.emit_obj._emit_api.get_engine()
-        interaction = eng.analyze(domain._obj)
+        self.emit_obj._load_result_set(self.path)
+        engine = self.emit_obj._emit_api.get_engine()
+        interaction = engine.run(domain)
         return interaction
 
     @pyaedt_function_handler()
-    def get_max_simultaneous_frequencies(self):
+    def get_max_simultaneous_interferers(self):
 
         """
-        Get the number of maximum simultaneous frequencies
+        Get the number of maximum simultaneous interferers.
 
         Returns
         -------
@@ -418,24 +254,38 @@ class Revision:
 
         Examples
         ----------
-        >>> max_num = aedtapp.results.get_max_simultaneous_frequencies()
+        >>> max_num = aedtapp.results.get_max_simultaneous_interferers()
         """
-        eng = self.emit_obj._emit_api.get_engine()
-        max_interferers = eng.max_simultaneous_interferers
+        engine = self.emit_obj._emit_api.get_engine()
+        max_interferers = engine.max_simultaneous_interferers
         return max_interferers
 
     @pyaedt_function_handler()
-    def set_max_simultaneous_frequencies(self, val):
+    def set_max_simultaneous_interferers(self, val):
 
         """
-        Set the number of maximum simultaneous frequencies
+        Set the number of maximum simultaneous interferers.
 
         Examples
         ----------
-        >>> max_num = aedtapp.results.get_max_simultaneous_frequencies()
+        >>> max_num = aedtapp.results.get_max_simultaneous_interferers()
         """
-        eng = self.emit_obj._emit_api.get_engine()
-        eng.max_simultaneous_interferers = val
+        engine = self.emit_obj._emit_api.get_engine()
+        engine.max_simultaneous_interferers = val
+
+    @pyaedt_function_handler()
+    def is_domain_valid(self, ret_val, domain):
+        """
+        Return ``True`` if the given domain is valid for the current Revision
+
+        Examples
+        ----------
+        >>> domain = aedtapp.interaction_domain()
+        >>> aedtapp.results.is_domain_valid(domain)
+        True
+        """
+        engine = self.emit_obj._emit_api.get_engine()
+        return engine.is_domain_valid(domain)
 
 
 class Emit(FieldAnalysisEmit, object):
@@ -515,7 +365,7 @@ class Emit(FieldAnalysisEmit, object):
     A revision within PyAEDT is analogous to a revision in AEDT. An interaction domain must
     be defined and then used as the input to the run command used on that revision.
 
-    >>> domain = Interaction_Domain()
+    >>> domain = aedtapp.interaction_domain()
     >>> domain.rx_radio_name = "UE - HandHeld"
     >>> interaction = aedtapp.revisions_list[0].run(domain)
 
@@ -562,14 +412,35 @@ class Emit(FieldAnalysisEmit, object):
             port=port,
             aedt_process_id=aedt_process_id,
         )
+        # aedt delcross python from custom path if any (for developers)
+        delcross_python_path = os.environ.get("ANSYS_DELCROSS_PYTHON_PATH")
+        if delcross_python_path:
+            sys.path.append(delcross_python_path)
+        # installed aedt delcross python path
         desktop_path = self.desktop_install_dir
         path = os.path.join(desktop_path, "Delcross")
         sys.path.append(path)
+
+        self.units = {
+            "Power": "dBm",
+            "Frequency": "MHz",
+            "Length": "meter",
+            "Time": "ns",
+            "Voltage": "mV",
+            "Data Rate": "bps",
+            "Resistance": "ohm",
+        }
+        """Default Emit units."""
+
         if self._aedt_version >= "2023.1":
             global mod
             mod = import_module("EmitApiPython")
             self._emit_api = mod.EmitApi()
-            self.results = Result(self)
+            """Instance of the Emit api."""
+
+            self.results = Results(self)
+            """''Result'' object for the selected design."""
+
             self.__emit_api_enabled = True
 
     @pyaedt_function_handler()
@@ -577,49 +448,49 @@ class Emit(FieldAnalysisEmit, object):
         return self
 
     @pyaedt_function_handler()
-    def analyze(self):
+    def analyze(self, revision_num=-1):
         """
         Analyze the active design.
 
         Returns
         -------
         rev:class:`pyaedt.modules.Revision`
-            last Revision object which was generated
+            Last ``Revision`` object that was generated.
 
         Examples
-        ----------
+        --------
         >>> rev = aedtapp.analyze()
 
         """
         if self.__emit_api_enabled:
             design = self.odesktop.GetActiveProject().GetActiveDesign()
-            if not self.results.current_design == design.getRevision():
+            if not self.results.current_design == design.GetRevision():
                 design.AddResult()
                 self.results.revisions_list.append(Revision(self))
-                self.results.current_design = design.getRevision()
+                self.results.current_design = design.GetRevision()
                 print("checkpoint - revision generated successfully")
-                domain = Interaction_Domain()
-                self.results.revisions_list[-1].run(domain)
-                rev = self.results.revisions_list[-1]
-                return rev
+            domain = Emit.interaction_domain()
+            self.results.revisions_list[revision_num].run(domain)
+            rev = self.results.revisions_list[revision_num]
+            return rev
 
     @pyaedt_function_handler()
-    def _load_revision(self, path):
+    def _load_result_set(self, path):
         """
-        Load a specific revision.
+        Load a specific result set.
 
         Parameters
         ----------
         path : str
-            Path to an AEDT result file.
+            Path to an AEDT EMIT result file.
 
         Examples
         ----------
-        >>> aedtapp._load_revision(path)
+        >>> aedtapp._load_result_set(path)
 
         """
         if self.__emit_api_enabled:
-            self._emit_api.load_result(path)
+            self._emit_api.load_project(path)
             self.results.result_loaded = True
             print(self.results.result_loaded)
 
@@ -631,7 +502,7 @@ class Emit(FieldAnalysisEmit, object):
         Returns
         -------
         result :class:`result_type`
-            result type object which can later be assigned a status (emi, sensitivity, desense)
+            Result type object which can later be assigned a status (emi, sensitivity, desense).
 
         Examples
         --------
@@ -653,8 +524,8 @@ class Emit(FieldAnalysisEmit, object):
 
         Returns
         -------
-        tx_rx :class:`Emit.tx_rx_mode`
-            mode status which can later be assigned a status (tx, rx)
+        :class:`Emit.tx_rx_mode`
+            Mode status which can later be assigned a status (tx, rx).
 
         Examples
         --------
@@ -669,6 +540,29 @@ class Emit(FieldAnalysisEmit, object):
             )
         return tx_rx
 
+    @staticmethod
+    def interaction_domain():
+        """
+        Get an ``InteractionDomain`` object.
+
+        Returns
+        -------
+        :class:`Emit.InteractionDomain`
+            Defines a set of interacting interferers and receivers.
+
+        Examples
+        --------
+        >>> domain = Emit.InteractionDomain()
+
+        """
+        try:
+            domain = mod.InteractionDomain()
+        except NameError:
+            raise ValueError(
+                "An Emit object must be initialized before any static member of the Result or Emit class is accessed."
+            )
+        return domain
+
     @pyaedt_function_handler()
     def version(self, detailed=False):
         """
@@ -682,7 +576,7 @@ class Emit(FieldAnalysisEmit, object):
         Returns
         -------
         ver : str
-            All of the version information
+            All of the version information.
 
         Examples
         --------
@@ -692,3 +586,82 @@ class Emit(FieldAnalysisEmit, object):
         if self.__emit_api_enabled:
             ver = self._emit_api.get_version(detailed)
             return ver
+
+    @pyaedt_function_handler()
+    def set_units(self, unit_type, unit_value):
+        """Set units for the component.
+
+        Parameters
+        ----------
+        unit_type : str
+            System of units.
+        unit_value : str
+            Units to use.
+
+        Power : mW, W, kW, dBm, dBW
+        Frequency : Hz, kHz, MHz, GHz, THz
+        Length : pm, nm, um, mm, cm, dm, meter, km, mil, in, ft, yd, mile
+        Time : ps, ns, us, ms, s
+        Voltage : mV, V
+        Data Rate : bps, kbps, Mbps, Gbps
+        Resistance : uOhm, mOhm, Ohm, kOhm, megOhm, GOhm
+
+        Returns
+        -------
+        Bool
+            ``True`` if the units were successfully changed and ``False``
+            if there was an error.
+        """
+        valid_type = EmitConstants.EMIT_UNIT_TYPE
+        valid_units = EmitConstants.EMIT_VALID_UNITS
+
+        if isinstance(unit_type, list):
+            for t, v in zip(unit_type, unit_value):
+                if t not in valid_type:
+                    warnings.warn("[{}] units are not supported by EMIT. The options are: {}: ".format(t, valid_type))
+                    return False
+                if v not in valid_units[t]:
+                    warnings.warn("[{}] are not supported by EMIT. The options are: {}: ".format(v, valid_units[t]))
+                    return False
+                self.units[t] = v
+        else:
+            if unit_type not in valid_type:
+                warnings.warn(
+                    "[{}] units are not supported by EMIT. The options are: {}: ".format(unit_type, valid_type)
+                )
+                return False
+            if unit_value not in valid_units[unit_type]:
+                warnings.warn(
+                    "[{}] are not supported by EMIT. The options are: {}: ".format(unit_value, valid_units[unit_type])
+                )
+                return False
+            self.units[unit_type] = unit_value
+        return True
+
+    @pyaedt_function_handler()
+    def get_units(self, unit_type=""):
+        """Get units for the component.
+
+        Parameters
+        ----------
+        unit_type : str
+            System of units: options are power, frequency,
+                length, time, voltage, data rate, or resistance.
+
+        Returns
+        -------
+        Str or Tuple
+            If unit_type is specified returns the units for that type
+            and if unit_type="", returns a Tuple of all units.
+        """
+        if not unit_type:
+            units = [(k, v) for k, v in self.units.items()]
+            return units
+        if unit_type not in EmitConstants.EMIT_UNIT_TYPE:
+            warnings.warn(
+                "[{}] units are not supported by EMIT. The options are: {}: ".format(
+                    unit_type, EmitConstants.EMIT_UNIT_TYPE
+                )
+            )
+            return None
+        return self.units[unit_type]
