@@ -50,7 +50,7 @@ def Hfss(
     port=0,
     aedt_process_id=None,
 ):
-    """Return the Hfss Class."""
+    """Return an instance of the Hfss Class."""
     from pyaedt.hfss import Hfss as app
 
     return app(
@@ -488,6 +488,87 @@ def Desktop(
     )
 
 
+def launch_desktop(
+    specified_version=None,
+    non_graphical=False,
+    new_desktop_session=True,
+    close_on_exit=True,
+    student_version=False,
+    machine="",
+    port=0,
+    aedt_process_id=None,
+):
+    """Initializes AEDT based on the inputs provided.
+
+    Parameters
+    ----------
+    specified_version : str, optional
+        Version of AEDT to use. The default is ``None``, in which case the
+        active setup or latest installed version is used.
+    non_graphical : bool, optional
+        Whether to launch AEDT in non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in graphical mode.
+        This parameter is ignored when a script is launched within AEDT.
+    new_desktop_session : bool, optional
+        Whether to launch an instance of AEDT in a new thread, even if
+        another instance of the ``specified_version`` is active on the machine.
+        The default is ``True``.
+    close_on_exit : bool, optional
+        Whether to close AEDT on exit. The default is ``True``.
+    student_version : bool, optional
+        Whether to open the AEDT student version. The default is
+        ``False``.
+    machine : str, optional
+        Machine name to connect the oDesktop session to. This parameters works only in 2022 R2
+        and later. The remote server must be up and running with the command
+        `"ansysedt.exe -grpcsrv portnum"`. If the machine is `"localhost"`, the server also
+        starts if not present.
+    port : int, optional
+        Port number on which to start the oDesktop communication on the already existing server.
+        This parameter is ignored when creating a new server. It works only in 2022 R2 and
+        later. The remote server must be up and running with the command `"ansysedt.exe -grpcsrv portnum"`.
+    aedt_process_id : int, optional
+        Process ID for the instance of AEDT to point PyAEDT at. The default is
+        ``None``. This parameter is only used when ``new_desktop_session = False``.
+
+    Returns
+    -------
+    :class:`pyaedt.desktop.Desktop`
+
+
+    Examples
+    --------
+    Launch AEDT 2021 R1 in non-graphical mode and initialize HFSS.
+
+    >>> import pyaedt
+    >>> desktop = pyaedt.launch_desktop("2022.2", non_graphical=True)
+    pyaedt INFO: pyaedt v...
+    pyaedt INFO: Python version ...
+    >>> hfss = pyaedt.Hfss(designname="HFSSDesign1")
+    pyaedt INFO: Project...
+    pyaedt INFO: Added design 'HFSSDesign1' of type HFSS.
+
+    Launch AEDT 2021 R1 in graphical mode and initialize HFSS.
+
+    >>> desktop = Desktop("2021.2")
+    pyaedt INFO: pyaedt v...
+    pyaedt INFO: Python version ...
+    >>> hfss = pyaedt.Hfss(designname="HFSSDesign1")
+    pyaedt INFO: No project is defined. Project...
+    """
+    d = Desktop(
+        specified_version=specified_version,
+        non_graphical=non_graphical,
+        new_desktop_session=new_desktop_session,
+        close_on_exit=close_on_exit,
+        student_version=student_version,
+        machine=machine,
+        port=port,
+        aedt_process_id=aedt_process_id,
+    )
+    return d
+
+
 def Edb(
     edbpath=None,
     cellname=None,
