@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
 import ast
 import codecs
 import csv
@@ -17,10 +20,11 @@ import sys
 import tempfile
 import time
 import traceback
-import warnings
 from collections import OrderedDict
 from functools import update_wrapper
 
+from pyaedt.generic.constants import CSS4_COLORS
+
 is_ironpython = "IronPython" in sys.version or ".NETFramework" in sys.version
 _pythonver = sys.version_info[0]
 inside_desktop = True
@@ -40,17 +44,19 @@ if not is_ironpython:
     try:
         import pandas as pd
     except ImportError:
-        warnings.warn(
-            "The Pandas module is required to run some functionalities.\n" "Install with \n\npip install pandas\n"
-        )
+
         pd = None
     try:
         import numpy as np
     except ImportError:
-        warnings.warn(
-            "The NumPy module is required to run some functionalities of PostProcess.\n"
-            "Install with \n\npip install numpy\n"
-        )
+        np = None
+
+try:
+    import xml.etree.cElementTree as ET
+
+    ET.VERSION
+except ImportError:
+    ET = None
 
 
 class MethodNotSupportedError(Exception):
@@ -920,6 +926,8 @@ def com_active_sessions(version=None, student_version=False, non_graphical=False
         keys = ["ansysedt.exe"]
     if version and "." in version:
         version = version[-4:].replace(".", "")
+    if version < "222":
+        version = version[:2] + "." + version[2]
     sessions = []
     for p in psutil.process_iter():
         try:
@@ -989,7 +997,8 @@ def compute_fft(time_vals, value):
     tuple
         Frequency and Values.
     """
-
+    if not np:
+        logging.error("Numpy is not available. Please, install it first.")
     deltaT = time_vals[-1] - time_vals[0]
     num_points = len(time_vals)
     valueFFT = np.fft.fft(value, num_points)
@@ -1037,6 +1046,8 @@ def parse_excitation_file(
     tuple
         Frequency, magnitude and phase.
     """
+    if not np:
+        logging.error("Numpy is not available. Please, install it first.")
     df = read_csv_pandas(file_name, encoding=encoding)
     if is_time_domain:
         time = df[df.keys()[0]].values * x_scale
@@ -1070,6 +1081,64 @@ def parse_excitation_file(
     return freq, mag, phase
 
 
+def tech_to_control_file(tech_path, unit="nm", control_path=None):
+    """Convert a TECH file to an XML file for use in a GDS or DXF import.
+
+    Parameters
+    ----------
+    tech_path : str
+        Full path to the TECH file.
+    unit : str, optional
+        Tech units. If specified in tech file this parameter will not be used. Default is ``"nm"``.
+    control_path : str, optional
+        Path for outputting the XML file.
+
+    Returns
+    -------
+    str
+        Out xml file.
+    """
+    result = []
+    with open(tech_path) as f:
+        vals = list(CSS4_COLORS.values())
+        id_layer = 0
+        for line in f:
+            line_split = line.split()
+            if len(line_split) == 5:
+                layerID, layer_name, _, elevation, layer_height = line.split()
+                x = '      <Layer Color="{}" GDSIIVia="{}" Name="{}" TargetLayer="{}" Thickness="{}"'.format(
+                    vals[id_layer],
+                    "true" if layer_name.lower().startswith("v") else "false",
+                    layerID,
+                    layer_name,
+                    layer_height,
+                )
+                x += ' Type="conductor"/>'
+                result.append(x)
+                id_layer += 1
+            elif len(line_split) > 1 and "UNIT" in line_split[0]:
+                unit = line_split[1]
+    if not control_path:
+        control_path = os.path.splitext(tech_path)[0] + ".xml"
+    with open(control_path, "w") as f:
+        f.write('<?xml version="1.0" encoding="UTF-8" standalone="no" ?>\n')
+        f.write('    <c:Control xmlns:c="http://www.ansys.com/control" schemaVersion="1.0">\n')
+        f.write("\n")
+        f.write('      <Stackup schemaVersion="1.0">\n')
+        f.write('        <Layers LengthUnit="{}">\n'.format(unit))
+        for res in result:
+            f.write(res + "\n")
+
+        f.write("    </Layers>\n")
+        f.write("  </Stackup>\n")
+        f.write("\n")
+        f.write('  <ImportOptions Flatten="true" GDSIIConvertPolygonToCircles="false" ImportDummyNet="true"/>\n')
+        f.write("\n")
+        f.write("</c:Control>\n")
+
+    return control_path
+
+
 class PropsManager(object):
     def __getitem__(self, item):
         """Get the `self.props` key value.
@@ -1178,8 +1247,156 @@ class PropsManager(object):
         pass
 
 
+clamp = lambda n, minn, maxn: max(min(maxn, n), minn)
+rgb_color_codes = {
+    "Black": (0, 0, 0),
+    "Green": (0, 128, 0),
+    "White": (255, 255, 255),
+    "Red": (255, 0, 0),
+    "Lime": (0, 255, 0),
+    "Blue": (0, 0, 255),
+    "Yellow": (255, 255, 0),
+    "Cyan": (0, 255, 255),
+    "Magenta": (255, 0, 255),
+    "Silver": (192, 192, 192),
+    "Gray": (128, 128, 128),
+    "Maroon": (128, 0, 0),
+    "Olive": (128, 128, 0),
+    "Purple": (128, 0, 128),
+    "Teal": (0, 128, 128),
+    "Navy": (0, 0, 128),
+    "copper": (184, 115, 51),
+    "stainless steel": (224, 223, 219),
+}
+
+
+@pyaedt_function_handler()
+def _arg2dict(arg, dict_out):
+    if arg[0] == "NAME:DimUnits" or "NAME:Point" in arg[0]:
+        if arg[0][5:] in dict_out:
+            if isinstance(dict_out[arg[0][5:]][0], (list, tuple)):
+                dict_out[arg[0][5:]].append(list(arg[1:]))
+            else:
+                dict_out[arg[0][5:]] = [dict_out[arg[0][5:]]]
+                dict_out[arg[0][5:]].append(list(arg[1:]))
+        else:
+            dict_out[arg[0][5:]] = list(arg[1:])
+    elif arg[0][:5] == "NAME:":
+        top_key = arg[0][5:]
+        dict_in = OrderedDict()
+        i = 1
+        while i < len(arg):
+            if arg[i][0][:5] == "NAME:" and (
+                isinstance(arg[i], (list, tuple)) or str(type(arg[i])) == r"<type 'List'>"
+            ):
+                _arg2dict(list(arg[i]), dict_in)
+                i += 1
+            elif arg[i][-2:] == ":=":
+                if str(type(arg[i + 1])) == r"<type 'List'>":
+                    if arg[i][:-2] in dict_in:
+                        dict_in[arg[i][:-2]].append(list(arg[i + 1]))
+                    else:
+                        dict_in[arg[i][:-2]] = list(arg[i + 1])
+                else:
+                    if arg[i][:-2] in dict_in:
+                        if isinstance(dict_in[arg[i][:-2]], list):
+                            dict_in[arg[i][:-2]].append(arg[i + 1])
+                        else:
+                            dict_in[arg[i][:-2]] = [dict_in[arg[i][:-2]]]
+                            dict_in[arg[i][:-2]].append(arg[i + 1])
+                    else:
+                        dict_in[arg[i][:-2]] = arg[i + 1]
+
+                i += 2
+            else:
+                raise ValueError("Incorrect data argument format")
+        if top_key in dict_out:
+            if isinstance(dict_out[top_key], list):
+                dict_out[top_key].append(dict_in)
+            else:
+                dict_out[top_key] = [dict_out[top_key], dict_in]
+        else:
+            dict_out[top_key] = dict_in
+    else:
+        raise ValueError("Incorrect data argument format")
+
+
+def _uname(name=None):
+    """Append a 6-digit hash code to a specified name.
+
+    Parameters
+    ----------
+    name : str
+        Name to append the hash code to. The default is ``"NewObject_"``.
+
+    Returns
+    -------
+    str
+
+    """
+    char_set = string.ascii_uppercase + string.digits
+    unique_name = "".join(random.sample(char_set, 6))
+    if name:
+        return name + unique_name
+    else:
+        return "NewObject_" + unique_name
+
+
+@pyaedt_function_handler()
+def _to_boolean(val):
+    """Retrieve the Boolean value of the provided input.
+
+        If the value is a Boolean, return the value.
+        Otherwise check to see if the value is in
+        ["false", "f", "no", "n", "none", "0", "[]", "{}", "" ]
+        and return True if the value is not in the list.
+
+    Parameters
+    ----------
+    val : bool or str
+        Input value to test for True/False condition.
+
+    Returns
+    -------
+    bool
+
+    """
+
+    if val is True or val is False:
+        return val
+
+    false_items = ["false", "f", "no", "n", "none", "0", "[]", "{}", ""]
+
+    return not str(val).strip().lower() in false_items
+
+
+@pyaedt_function_handler()
+def _dim_arg(value, units):
+    """Concatenate a specified units string to a numerical input.
+
+    Parameters
+    ----------
+    value : str or number
+        Valid expression string in the AEDT modeler. For example, ``"5mm"``.
+    units : str
+        Valid units string in the AEDT modeler. For example, ``"mm"``.
+
+    Returns
+    -------
+    str
+
+    """
+    try:
+        val = float(value)
+        if isinstance(value, int):
+            val = value
+        return str(val) + units
+    except:
+        return value
+
+
 class Settings(object):
-    """Class that manages all PyAEDT environment variables and global settings."""
+    """Manages all PyAEDT environment variables and global settings."""
 
     def __init__(self):
         self._enable_logger = True
@@ -1199,7 +1416,7 @@ class Settings(object):
         self._non_graphical = False
         self.aedt_version = None
         self.remote_api = False
-        self._use_grpc_api = False
+        self._use_grpc_api = None
         self.machine = ""
         self.port = 0
         self.formatter = None
@@ -1216,6 +1433,22 @@ class Settings(object):
         self._enable_global_log_file = True
         self._enable_local_log_file = False
         self._global_log_file_size = 10
+        self._edb_dll_path = None
+
+    @property
+    def edb_dll_path(self):
+        """Get/Set an optional path for Edb Dll.
+
+        Returns
+        -------
+        bool
+        """
+        return self._edb_dll_path
+
+    @edb_dll_path.setter
+    def edb_dll_path(self, value):
+        if os.path.exists(value):
+            self._edb_dll_path = value
 
     @property
     def global_log_file_size(self):
@@ -1378,7 +1611,7 @@ class Settings(object):
     @property
     def enable_desktop_logs(self):
         """Get the content for the environment variable."""
-        return self._enable_desktop_logs
+        return False if self.non_graphical else self._enable_desktop_logs
 
     @enable_desktop_logs.setter
     def enable_desktop_logs(self, val):
