@@ -1,5 +1,6 @@
 import ast
 import csv
+import math
 import os
 import tempfile
 import time
@@ -412,16 +413,17 @@ def plot_2d_chart(plot_data, size=(2000, 1000), show_legend=True, xlabel="", yla
         `[x points, y points, label]`.
     size : tuple, optional
         Image size in pixel (width, height).
-    show_legend : bool
-        Either to show legend or not.
-    xlabel : str
-        Plot X label.
-    ylabel : str
-        Plot Y label.
-    title : str
-        Plot Title label.
-    snapshot_path : str
+    show_legend : bool, optional
+        Either to show legend or not. The default value is ``True``.
+    xlabel : str, optional
+        Plot X label. The default value is ``""``.
+    ylabel : str, optional
+        Plot Y label. The default value is ``""``.
+    title : str, optional
+        Plot Title label. The default value is ``""``.
+    snapshot_path : str, optional
         Full path to image file if a snapshot is needed.
+        The default value is ``None``.
 
     Returns
     -------
@@ -572,7 +574,7 @@ def plot_contour(qty_to_plot, x, y, size=(2000, 1600), xlabel="", ylabel="", tit
 
 
 class ObjClass(object):
-    """Class that manages mesh files to be plotted in pyvista.
+    """Manages mesh files to be plotted in pyvista.
 
     Parameters
     ----------
@@ -665,12 +667,12 @@ class FieldClass(object):
 
 
 class ModelPlotter(object):
-    """Class that manage the plot data.
+    """Manages the data to be plotted with ``pyvista``.
 
     Examples
     --------
     This Class can be instantiated within Pyaedt (with plot_model_object or different field plots
-    and standalone.
+    and standalone).
     Here an example of standalone project
 
     >>> model = ModelPlotter()
@@ -702,6 +704,7 @@ class ModelPlotter(object):
         self.is_notebook = is_notebook()
         self.gif_file = None
         self._background_color = (255, 255, 255)
+        self._background_image = None
         self.off_screen = False
         if self.is_notebook:
             self.windows_size = [600, 600]
@@ -727,6 +730,70 @@ class ModelPlotter(object):
         self.color_bar = True
         self.array_coordinates = []
         self.meshes = None
+        self._x_scale = 1.0
+        self._y_scale = 1.0
+        self._z_scale = 1.0
+        self._convert_fields_in_db = False
+
+    @property
+    def convert_fields_in_db(self):
+        """Either if convert the fields before plotting in dB10. Log scale will be disabled.
+
+        Returns
+        -------
+        bool
+        """
+        return self._convert_fields_in_db
+
+    @convert_fields_in_db.setter
+    def convert_fields_in_db(self, value):
+        self._convert_fields_in_db = value
+        for f in self.fields:
+            f._cached_polydata = None
+        for f in self.frames:
+            f._cached_polydata = None
+
+    @property
+    def x_scale(self):
+        """Scale plot on X.
+
+        Returns
+        -------
+        float
+        """
+        return self._x_scale
+
+    @x_scale.setter
+    def x_scale(self, value):
+        self._x_scale = value
+
+    @property
+    def y_scale(self):
+        """Scale plot on Y.
+
+        Returns
+        -------
+        float
+        """
+        return self._y_scale
+
+    @y_scale.setter
+    def y_scale(self, value):
+        self._y_scale = value
+
+    @property
+    def z_scale(self):
+        """Scale plot on Z.
+
+        Returns
+        -------
+        float
+        """
+        return self._z_scale
+
+    @z_scale.setter
+    def z_scale(self, value):
+        self._z_scale = value
 
     @property
     def isometric_view(self):
@@ -795,12 +862,8 @@ class ModelPlotter(object):
 
     @property
     def camera_position(self):
-        """Get/Set the camera position value. It disables the default iso view.
-
-        Parameters
-        ----------
-        value : str or tuple
-            Value of camera position. One of `"xy"`, `"xz"`,`"yz"`.
+        """Get or set the camera position value. This parameter disables the default iso view.
+        Value for the camera position. The value is for ``"xy"``, ``"xz"`` or ``"yz"``.
 
         Returns
         -------
@@ -938,6 +1001,21 @@ class ModelPlotter(object):
             h = CSS4_COLORS[value].lstrip("#")
             self._background_color = tuple(int(h[i : i + 2], 16) for i in (0, 2, 4))
 
+    @property
+    def background_image(self):
+        """Background image.
+
+        Returns
+        -------
+        str
+        """
+        return self._background_image
+
+    @background_image.setter
+    def background_image(self, value):
+        if os.path.exists(value):
+            self._background_image = value
+
     @property
     def fields(self):
         """List of fields object.
@@ -1167,6 +1245,8 @@ class ModelPlotter(object):
             if field.path and not field._cached_polydata:
                 if ".aedtplt" in field.path:
                     vertices, faces, scalars, log1 = _parse_aedtplt(field.path)
+                    if self.convert_fields_in_db:
+                        scalars = [np.multiply(np.log10(i), 10) for i in scalars]
                     fields_vals = pv.PolyData(vertices[0], faces[0])
                     field._cached_polydata = fields_vals
                     if isinstance(scalars[0], list):
@@ -1216,6 +1296,11 @@ class ModelPlotter(object):
                                 is_vector = True
                             else:
                                 values.append(float(tmp[3]))
+                    if self.convert_fields_in_db:
+                        if len(values[0]) == 1:
+                            values = [10 * math.log10(i) for i in values]
+                        else:
+                            values = [[10 * math.log10(i) for i in value] for value in values]
                     if nodes:
                         try:
                             conv = 1 / AEDT_UNITS["Length"][self.units]
@@ -1355,7 +1440,10 @@ class ModelPlotter(object):
         """
         self.pv = pv.Plotter(notebook=self.is_notebook, off_screen=self.off_screen, window_size=self.windows_size)
         self.meshes = None
-        self.pv.background_color = [i / 255 for i in self.background_color]
+        if self.background_image:
+            self.pv.add_background_image(self.background_image)
+        else:
+            self.pv.background_color = [i / 255 for i in self.background_color]
         self._read_mesh_files()
         axes_color = [0 if i >= 128 else 1 for i in self.background_color]
         if self.color_bar:
@@ -1383,7 +1471,7 @@ class ModelPlotter(object):
                 self.pv.add_mesh(
                     field._cached_polydata.arrows,
                     scalars=field.label,
-                    log_scale=field.log_scale,
+                    log_scale=False if self.convert_fields_in_db else field.log_scale,
                     scalar_bar_args=sargs,
                     cmap=field.color_map,
                 )
@@ -1392,7 +1480,7 @@ class ModelPlotter(object):
                 field._cached_mesh = self.pv.add_mesh(
                     field._cached_polydata,
                     scalars=field.label,
-                    log_scale=field.log_scale,
+                    log_scale=False if self.convert_fields_in_db else field.log_scale,
                     scalar_bar_args=sargs,
                     cmap=field.color_map,
                     clim=[self.range_min, self.range_max],
@@ -1403,12 +1491,15 @@ class ModelPlotter(object):
                 field._cached_mesh = self.pv.add_mesh(
                     field._cached_polydata,
                     scalars=field.label,
-                    log_scale=field.log_scale,
+                    log_scale=False if self.convert_fields_in_db else field.log_scale,
                     scalar_bar_args=sargs,
                     cmap=field.color_map,
                     opacity=field.opacity,
                     show_edges=field.show_edge,
                 )
+
+        self.pv.set_scale(self.x_scale, self.y_scale, self.z_scale)
+
         if self.show_legend:
             self._add_buttons()
 
@@ -1504,12 +1595,15 @@ class ModelPlotter(object):
             self.pv = pv.Plotter(notebook=self.is_notebook, off_screen=True, window_size=self.windows_size)
         else:
             self.pv = pv.Plotter(notebook=self.is_notebook, off_screen=self.off_screen, window_size=self.windows_size)
-
-        self.pv.background_color = [i / 255 for i in self.background_color]
+        if self.background_image:
+            self.pv.add_background_image(self.background_image)
+        else:
+            self.pv.background_color = [i / 255 for i in self.background_color]
         self._read_mesh_files(read_frames=True)
 
         axes_color = [0 if i >= 128 else 1 for i in self.background_color]
 
+        self.pv.set_scale(self.x_scale, self.y_scale, self.z_scale)
         if self.show_axes:
             self.pv.show_axes()
         if self.show_grid and not self.is_notebook:
@@ -1577,7 +1671,7 @@ class ModelPlotter(object):
             field._cached_mesh = self.pv.add_mesh(
                 field._cached_polydata,
                 scalars=field.label,
-                log_scale=field.log_scale,
+                log_scale=False if self.convert_fields_in_db else field.log_scale,
                 scalar_bar_args=sargs,
                 cmap=field.color_map,
                 opacity=field.opacity,
@@ -1603,7 +1697,7 @@ class ModelPlotter(object):
         self.frames[0]._cached_mesh = self.pv.add_mesh(
             self.frames[0]._cached_polydata,
             scalars=self.frames[0].label,
-            log_scale=self.frames[0].log_scale,
+            log_scale=False if self.convert_fields_in_db else self.frames[0].log_scale,
             scalar_bar_args=sargs,
             cmap=self.frames[0].color_map,
             clim=[mins, maxs],
@@ -1614,8 +1708,10 @@ class ModelPlotter(object):
             opacity=self.frames[0].opacity,
         )
         start = time.time()
-
-        self.pv.update(1, force_redraw=True)
+        try:
+            self.pv.update(1, force_redraw=True)
+        except:
+            pass
         if self.gif_file:
             first_loop = True
             self.pv.write_frame()
