@@ -14,6 +14,7 @@ from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import parse_excitation_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.generic.general_methods import tech_to_control_file
 from pyaedt.modules.Boundary import BoundaryObject3dLayout
 
 
@@ -151,7 +152,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
 
         Parameters
         ----------
-        primivitivename : str
+        primivitivename : str or :class:`pyaedt.modeler.object3dlayout.Line3dLayout`
             Name of the primitive to create the edge port on.
         edgenumber :
             Edge number to create the edge port on.
@@ -182,6 +183,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
 
         >>> oEditor.CreateEdgePort
         """
+        primivitivename = self.modeler.convert_to_selections(primivitivename, False)
         listp = self.port_list
         self.modeler.oeditor.CreateEdgePort(
             [
@@ -1231,6 +1233,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             self.logger.warning("aedb_exists. Renaming it to %s", project_name)
         if not xml_path:
             xml_path = ""
+        elif os.path.splitext(xml_path)[1] == ".tech":
+            xml_path = tech_to_control_file(xml_path)
         if cad_format == "gds":
             method(cad_path, aedb_path, xml_path, "")
         else:
@@ -1254,8 +1258,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         aedb_path : str, optional
             Full path to the AEDB file.
         control_file : str, optional
-            Path to the XML file with the stackup information. The default is ``None``, in
+            Path to the XML or TECH file with the stackup information. The default is ``None``, in
             which case the stackup is not edited.
+            If a TECH file is provided and the layer name starts with ``"v"``, the layer
+            is mapped as a via layer.
         set_as_active : bool, optional
             Whether to set the GDS file as active. The default is ``True``.
         close_active_project : bool, optional
@@ -1279,13 +1285,15 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
 
         Parameters
         ----------
-        gds_path : str
+        dxf_path : str
             Full path to the DXF file.
         aedb_path : str, optional
             Full path to the AEDB file.
         control_file : str, optional
-            Path to the XML file with the stackup information. The default is ``None``, in
+            Path to the XML or TECH file with the stackup information. The default is ``None``, in
             which case the stackup is not edited.
+            If a TECH file is provided and the layer name starts with ``"v"``, the layer
+            is mapped as a via layer.
         set_as_active : bool, optional
             Whether to set the DXF file as active. The default is ``True``.
         close_active_project : bool, optional
