@@ -1,4 +1,5 @@
 import copy
+import csv
 from collections import OrderedDict
 
 from pyaedt.generic.DataHandlers import _arg2dict
@@ -42,6 +43,10 @@ class CommonOptimetrics(PropsManager, object):
 
         if optimtype == "OptiParametric":
             self.props = SetupProps(self, inputd or copy.deepcopy(defaultparametricSetup))
+            if not inputd and self._app.design_type == "Icepak":
+                self.props["ProdOptiSetupDataV2"] = OrderedDict(
+                    {"SaveFields": False, "FastOptimetrics": False, "SolveWithCopiedMeshOnly": True}
+                )
         if optimtype == "OptiDesignExplorer":
             self.props = SetupProps(self, inputd or copy.deepcopy(defaultdxSetup))
         if optimtype == "OptiOptimization":
@@ -240,6 +245,12 @@ class CommonOptimetrics(PropsManager, object):
         arg = ["NAME:" + self.name]
         _dict2arg(self.props, arg)
 
+        if self.soltype == "OptiParametric" and len(arg[8]) == 3:
+            arg[8] = ["NAME:Sweep Operations"]
+            for variation in self.props["Sweep Operations"].get("add", []):
+                arg[8].append("add:=")
+                arg[8].append(variation)
+
         self.omodule.EditSetup(self.name, arg)
         return True
 
@@ -733,7 +744,7 @@ class SetupParam(CommonOptimetrics, object):
         Returns
         -------
         bool
-            `True` if setup is deleted. `False` if it failed.
+            ``True`` if setup is deleted. ``False`` if it failed.
         """
 
         self.omodule.DeleteSetups([self.name])
@@ -978,7 +989,6 @@ class ParametricSetups(object):
         parametricname=None,
     ):
         """Add a basic sensitivity analysis.
-
         You can customize all options after the analysis is added.
 
         Parameters
@@ -1042,7 +1052,7 @@ class ParametricSetups(object):
         Returns
         -------
         bool
-            `True` if setup is deleted. `False` if it failed.
+            ``True`` if setup is deleted. ``False`` if it failed.
         """
         for el in self.setups:
             if el.name == setup_name:
@@ -1068,9 +1078,61 @@ class ParametricSetups(object):
         """
         if not parametricname:
             parametricname = generate_unique_name("Parametric")
-        self.optimodule.ImportSetup("OptiParametric", ["NAME:" + parametricname, filename])
         setup = SetupParam(self._app, parametricname, optim_type="OptiParametric")
         setup.auto_update = False
+        setup.props["Sim. Setups"] = [setup_defined.name for setup_defined in self._app.setups]
+        with open(filename, "r") as csvfile:
+            csvreader = csv.DictReader(csvfile)
+            first_data_line = next(csvreader)
+            setup.props["Sweeps"] = {"SweepDefinition": OrderedDict()}
+            sweep_definition = []
+            for var_name in csvreader.fieldnames:
+                if var_name != "*":
+                    sweep_definition.append(
+                        OrderedDict(
+                            {
+                                "Variable": var_name,
+                                "Data": first_data_line[var_name],
+                                "OffsetF1": False,
+                                "Synchronize": 0,
+                            }
+                        )
+                    )
+            setup.props["Sweeps"]["SweepDefinition"] = sweep_definition
+
+            args = ["NAME:" + parametricname]
+            _dict2arg(setup.props, args)
+
+            setup.props["Sweep Operations"] = OrderedDict({"add": []})
+            table = []
+            for var_name in csvreader.fieldnames:
+                if var_name != "*":
+                    table.append(first_data_line[var_name])
+            table = [table]
+            for line in csvreader:
+                table_line = []
+                for var_name in csvreader.fieldnames:
+                    if var_name != "*":
+                        table_line.append(line[var_name])
+                table.append(table_line)
+
+            if len(table) > 1:
+                for point in table[1:]:
+                    setup.props["Sweep Operations"]["add"].append(point)
+
+        cont = 0
+        for data in args:
+            if isinstance(data, list) and "NAME:Sweep Operations" in data:
+                del args[cont]
+                args.append(["NAME:Sweep Operations"])
+                break
+            cont += 1
+
+        for variation in setup.props["Sweep Operations"].get("add", []):
+            args[-1].append("add:=")
+            args[-1].append(variation)
+
+        self.optimodule.InsertSetup("OptiParametric", args)
         self.setups.append(setup)
         return True
 
@@ -1132,7 +1194,7 @@ class OptimizationSetups(object):
         Returns
         -------
         bool
-            `True` if setup is deleted. `False` if it failed.
+            ``True`` if setup is deleted. ``False`` if it failed.
         """
         for el in self.setups:
             if el.name == setup_name:
@@ -1158,7 +1220,6 @@ class OptimizationSetups(object):
         report_type=None,
     ):
         """Add a basic optimization analysis.
-
         You can customize all options after the analysis is added.
 
         Parameters
@@ -1174,7 +1235,7 @@ class OptimizationSetups(object):
         optim_type : strm optional
             Optimization Type.
             Possible values are `"Optimization"`, `"DXDOE"`,`"DesignExplorer"`,`"Sensitivity"`,`"Statistical"`
-            and `"optiSLang"'.
+            and `"optiSLang"`.
         condition : string, optional
             The default is ``"<="``.
         goal_value : optional
