@@ -1274,6 +1274,7 @@ class Material(CommonMaterial, object):
                 )
             }
         )
+        self.update()
 
     @property
     def permittivity(self):
@@ -2084,7 +2085,7 @@ class Material(CommonMaterial, object):
         Returns
         -------
         tuple
-            Tuple of (Magnitude, x, y, z)
+            Tuple of (Magnitude, x, y, z).
         """
         if "magnetic_coercivity" in self._props:
             return (
@@ -2177,7 +2178,7 @@ class Material(CommonMaterial, object):
 
 
 class SurfaceMaterial(CommonMaterial, object):
-    """Manages surface material properties.
+    """Manages surface material properties for Icepak only.
 
     Parameters
     ----------
