@@ -190,14 +190,11 @@ class MeshOperation(PropsManager, object):
 
 
 class Mesh(object):
-    """Mesh class.
-
-    This class manages AEDT mesh functions.
+    """Manages AEDT mesh functions for 2D and 3D solvers (HFSS, Maxwell, and Q3D).
 
     Parameters
     ----------
     app : :class:`pyaedt.application.Analysis3D.FieldAnalysis3D`
-
     """
 
     def __init__(self, app):
@@ -349,7 +346,7 @@ class Mesh(object):
 
         Parameters
         ----------
-        names : list or str or :class:`pyaedt.modeler.Object3d.FacePrimitive`
+        names : list or str or :class:`pyaedt.modeler.elements3d.FacePrimitive`
             List of faces to apply the surface mesh to.
         surf_dev : float or str, optional
             Surface deviation. The default is ``None``. Allowed values are float, number with units or `"inf"`.
