@@ -213,7 +213,7 @@ class Setup(CommonSetup):
         Returns
         -------
         bool
-            `True` if setup is deleted. `False` if it failed.
+            ``True`` if setup is deleted. ``False`` if it failed.
         """
 
         self.omodule.DeleteSetups([self.name])
@@ -387,32 +387,6 @@ class Setup(CommonSetup):
         self.omodule.EditSetup(self.name, arg)
         return True
 
-    @pyaedt_function_handler()
-    def add_derivatives(self, derivative_list):
-        """Add derivatives to the setup.
-
-        Parameters
-        ----------
-        derivative_list : list
-            List of derivatives.
-
-        Returns
-        -------
-        bool
-            ``True`` when successful, ``False`` when failed.
-
-        References
-        ----------
-
-        >>> oModule.EditSetup
-        """
-        arg = ["NAME:" + self.name]
-        _dict2arg(self.props, arg)
-        arg.append("VariablesForDerivatives:=")
-        arg.append(derivative_list)
-        self.omodule.EditSetup(self.name, arg)
-        return True
-
     @pyaedt_function_handler()
     def enable(self, setup_name=None):
         """Enable a setup.
@@ -934,22 +908,22 @@ class SetupCircuit(CommonSetup):
             userelative = 0
 
         list_data = ["NAME:ExpressionCache"]
-        if type(expression_list) is list:
+        if isinstance(expression_list, list):
             i = 0
             while i < len(expression_list):
                 expression = expression_list[i]
                 name = expression.replace("(", "_") + "1"
                 name = name.replace(")", "_")
                 name = name.replace(" ", "_")
-                if type(report_type_list) is list:
+                if isinstance(report_type_list, list):
                     report_type = report_type_list[i]
                 else:
                     report_type = report_type_list
-                if type(isconvergence_list) is list:
+                if isinstance(isconvergence_list, list):
                     isconvergence = isconvergence_list[i]
                 else:
                     isconvergence = isconvergence_list
-                if type(intrinsics_list) is list:
+                if isinstance(intrinsics_list, list):
                     intrinsics = intrinsics_list[i]
                 else:
                     intrinsics = intrinsics_list
@@ -1057,32 +1031,6 @@ class SetupCircuit(CommonSetup):
         self.omodule.EditSetup(self.name, arg)
         return True
 
-    @pyaedt_function_handler()
-    def add_derivatives(self, derivative_list):
-        """Add derivatives to the setup.
-
-        Parameters
-        ----------
-        derivative_list : list
-            List of derivatives.
-
-        Returns
-        -------
-        bool
-            ``True`` when successful, ``False`` when failed.
-
-        References
-        ----------
-
-        >>> oModule.EditSetup
-        """
-        arg = ["Name:SimSetup"]
-        _dict2arg(self.props, arg)
-        arg.append("VariablesForDerivatives:=")
-        arg.append(derivative_list)
-        self.omodule.EditSetup(self.name, arg)
-        return True
-
     @pyaedt_function_handler()
     def enable(self, setup_name=None):
         """Enable a setup.
@@ -1454,6 +1402,45 @@ class SetupHFSS(Setup, object):
     def __init__(self, app, solutiontype, setupname="MySetupAuto", isnewsetup=True):
         Setup.__init__(self, app, solutiontype, setupname, isnewsetup)
 
+    @pyaedt_function_handler()
+    def get_derivative_variables(self):
+        """Return Derivative Enabled variables.
+
+        Returns
+        -------
+        List
+        """
+        try:
+            return list(self._app.oanalysis.GetDerivativeVariables(self.name))
+        except AttributeError:
+            return []
+
+    @pyaedt_function_handler()
+    def add_derivatives(self, derivative_list):
+        """Add derivatives to the setup.
+
+        Parameters
+        ----------
+        derivative_list : str or List
+            Derivative variable names.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oModule.EditSetup
+        """
+        if not isinstance(derivative_list, list):
+            derivative_list = [derivative_list]
+        self.auto_update = False
+        self.props["VariablesForDerivatives"] = derivative_list + self.get_derivative_variables()
+        self.auto_update = True
+        return self.update()
+
     @pyaedt_function_handler()
     def create_linear_count_sweep(
         self,
@@ -1929,6 +1916,45 @@ class SetupHFSSAuto(Setup, object):
     def __init__(self, app, solutiontype, setupname="MySetupAuto", isnewsetup=True):
         Setup.__init__(self, app, solutiontype, setupname, isnewsetup)
 
+    @pyaedt_function_handler()
+    def get_derivative_variables(self):
+        """Return Derivative Enabled variables.
+
+        Returns
+        -------
+        List
+        """
+        try:
+            return list(self._app.oanalysis.GetDerivativeVariables(self.name))
+        except AttributeError:
+            return []
+
+    @pyaedt_function_handler()
+    def add_derivatives(self, derivative_list):
+        """Add derivatives to the setup.
+
+        Parameters
+        ----------
+        derivative_list : str or List
+            Derivative variable names.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oModule.EditSetup
+        """
+        if not isinstance(derivative_list, list):
+            derivative_list = [derivative_list]
+        self.auto_update = False
+        self.props["VariablesForDerivatives"] = derivative_list + self.get_derivative_variables()
+        self.auto_update = True
+        return self.update()
+
     @pyaedt_function_handler()
     def add_subrange(self, rangetype, start, end=None, count=None, unit="GHz", clear=False):
         """Add a subrange to the sweep.
